/* AUTO-GENERATED FILE.  DO NOT MODIFY.
 *
 * This class was automatically generated by the
 * aapt tool from the resource data it found.  It
 * should not be modified by hand.
 */
package android.support.v7.recyclerview;

public final class R {
	public static final class attr {
		public static final int layoutManager = 0x7f010051;
		public static final int reverseLayout = 0x7f010053;
		public static final int spanCount = 0x7f010052;
		public static final int stackFromEnd = 0x7f010054;
	}
	public static final class dimen {
		public static final int item_touch_helper_max_drag_scroll_per_frame = 0x7f070045;
	}
	public static final class id {
		public static final int item_touch_helper_previous_elevation = 0x7f0c0005;
	}
	public static final class styleable {
		public static final int[] RecyclerView = { 0x010100c4, 0x7f010051, 0x7f010052, 0x7f010053, 0x7f010054 };
		public static final int RecyclerView_android_orientation = 0;
		public static final int RecyclerView_layoutManager = 1;
		public static final int RecyclerView_reverseLayout = 3;
		public static final int RecyclerView_spanCount = 2;
		public static final int RecyclerView_stackFromEnd = 4;
	}
}
