/* AUTO-GENERATED FILE.  DO NOT MODIFY.
 *
 * This class was automatically generated by the
 * aapt tool from the resource data it found.  It
 * should not be modified by hand.
 */
package com.facebook.drawee;

public final class R {
	public static final class attr {
		public static final int actualImageScaleType = 0x7f01003a;
		public static final int backgroundImage = 0x7f01003b;
		public static final int fadeDuration = 0x7f01002f;
		public static final int failureImage = 0x7f010035;
		public static final int failureImageScaleType = 0x7f010036;
		public static final int overlayImage = 0x7f01003c;
		public static final int placeholderImage = 0x7f010031;
		public static final int placeholderImageScaleType = 0x7f010032;
		public static final int pressedStateOverlayImage = 0x7f01003d;
		public static final int progressBarAutoRotateInterval = 0x7f010039;
		public static final int progressBarImage = 0x7f010037;
		public static final int progressBarImageScaleType = 0x7f010038;
		public static final int retryImage = 0x7f010033;
		public static final int retryImageScaleType = 0x7f010034;
		public static final int roundAsCircle = 0x7f01003e;
		public static final int roundBottomLeft = 0x7f010043;
		public static final int roundBottomRight = 0x7f010042;
		public static final int roundTopLeft = 0x7f010040;
		public static final int roundTopRight = 0x7f010041;
		public static final int roundWithOverlayColor = 0x7f010044;
		public static final int roundedCornerRadius = 0x7f01003f;
		public static final int roundingBorderColor = 0x7f010046;
		public static final int roundingBorderWidth = 0x7f010045;
		public static final int viewAspectRatio = 0x7f010030;
	}
	public static final class id {
		public static final int center = 0x7f0c0019;
		public static final int centerCrop = 0x7f0c001a;
		public static final int centerInside = 0x7f0c001b;
		public static final int fitCenter = 0x7f0c001c;
		public static final int fitEnd = 0x7f0c001d;
		public static final int fitStart = 0x7f0c001e;
		public static final int fitXY = 0x7f0c001f;
		public static final int focusCrop = 0x7f0c0020;
		public static final int none = 0x7f0c000f;
	}
	public static final class styleable {
		public static final int[] GenericDraweeView = { 0x7f01002f, 0x7f010030, 0x7f010031, 0x7f010032, 0x7f010033, 0x7f010034, 0x7f010035, 0x7f010036, 0x7f010037, 0x7f010038, 0x7f010039, 0x7f01003a, 0x7f01003b, 0x7f01003c, 0x7f01003d, 0x7f01003e, 0x7f01003f, 0x7f010040, 0x7f010041, 0x7f010042, 0x7f010043, 0x7f010044, 0x7f010045, 0x7f010046 };
		public static final int GenericDraweeView_actualImageScaleType = 11;
		public static final int GenericDraweeView_backgroundImage = 12;
		public static final int GenericDraweeView_fadeDuration = 0;
		public static final int GenericDraweeView_failureImage = 6;
		public static final int GenericDraweeView_failureImageScaleType = 7;
		public static final int GenericDraweeView_overlayImage = 13;
		public static final int GenericDraweeView_placeholderImage = 2;
		public static final int GenericDraweeView_placeholderImageScaleType = 3;
		public static final int GenericDraweeView_pressedStateOverlayImage = 14;
		public static final int GenericDraweeView_progressBarAutoRotateInterval = 10;
		public static final int GenericDraweeView_progressBarImage = 8;
		public static final int GenericDraweeView_progressBarImageScaleType = 9;
		public static final int GenericDraweeView_retryImage = 4;
		public static final int GenericDraweeView_retryImageScaleType = 5;
		public static final int GenericDraweeView_roundAsCircle = 15;
		public static final int GenericDraweeView_roundBottomLeft = 20;
		public static final int GenericDraweeView_roundBottomRight = 19;
		public static final int GenericDraweeView_roundTopLeft = 17;
		public static final int GenericDraweeView_roundTopRight = 18;
		public static final int GenericDraweeView_roundWithOverlayColor = 21;
		public static final int GenericDraweeView_roundedCornerRadius = 16;
		public static final int GenericDraweeView_roundingBorderColor = 23;
		public static final int GenericDraweeView_roundingBorderWidth = 22;
		public static final int GenericDraweeView_viewAspectRatio = 1;
	}
}
