/* AUTO-GENERATED FILE.  DO NOT MODIFY.
 *
 * This class was automatically generated by the
 * aapt tool from the resource data it found.  It
 * should not be modified by hand.
 */

package com.reactlibrary;

public final class R {
    public static final class anim {
        public static int abc_fade_in=0x7f040000;
        public static int abc_fade_out=0x7f040001;
        public static int abc_grow_fade_in_from_bottom=0x7f040002;
        public static int abc_popup_enter=0x7f040003;
        public static int abc_popup_exit=0x7f040004;
        public static int abc_shrink_fade_out_from_bottom=0x7f040005;
        public static int abc_slide_in_bottom=0x7f040006;
        public static int abc_slide_in_top=0x7f040007;
        public static int abc_slide_out_bottom=0x7f040008;
        public static int abc_slide_out_top=0x7f040009;
        public static int catalyst_push_up_in=0x7f04000a;
        public static int catalyst_push_up_out=0x7f04000b;
    }
    public static final class attr {
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionBarDivider=0x7f01007e;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionBarItemBackground=0x7f01007f;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionBarPopupTheme=0x7f010078;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
<p>May be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>wrap_content</code></td><td>0</td><td></td></tr>
</table>
         */
        public static int actionBarSize=0x7f01007d;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionBarSplitStyle=0x7f01007a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionBarStyle=0x7f010079;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionBarTabBarStyle=0x7f010074;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionBarTabStyle=0x7f010073;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionBarTabTextStyle=0x7f010075;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionBarTheme=0x7f01007b;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionBarWidgetTheme=0x7f01007c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionButtonStyle=0x7f010098;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionDropDownStyle=0x7f010094;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionLayout=0x7f01004b;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionMenuTextAppearance=0x7f010080;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static int actionMenuTextColor=0x7f010081;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModeBackground=0x7f010084;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModeCloseButtonStyle=0x7f010083;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModeCloseDrawable=0x7f010086;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModeCopyDrawable=0x7f010088;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModeCutDrawable=0x7f010087;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModeFindDrawable=0x7f01008c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModePasteDrawable=0x7f010089;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModePopupWindowStyle=0x7f01008e;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModeSelectAllDrawable=0x7f01008a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModeShareDrawable=0x7f01008b;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModeSplitBackground=0x7f010085;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModeStyle=0x7f010082;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionModeWebSearchDrawable=0x7f01008d;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionOverflowButtonStyle=0x7f010076;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int actionOverflowMenuStyle=0x7f010077;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int actionProviderClass=0x7f01004d;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int actionViewClass=0x7f01004c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int activityChooserViewStyle=0x7f0100a0;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
         */
        public static int actualImageScaleType=0x7f01003a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int alertDialogButtonGroupStyle=0x7f0100c2;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int alertDialogCenterButtons=0x7f0100c3;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int alertDialogStyle=0x7f0100c1;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int alertDialogTheme=0x7f0100c4;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int arrowHeadLength=0x7f01002b;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int arrowShaftLength=0x7f01002c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int autoCompleteTextViewStyle=0x7f0100c9;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int background=0x7f01000c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int backgroundImage=0x7f01003b;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static int backgroundSplit=0x7f01000e;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static int backgroundStacked=0x7f01000d;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int backgroundTint=0x7f0100e5;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>src_over</code></td><td>3</td><td></td></tr>
<tr><td><code>src_in</code></td><td>5</td><td></td></tr>
<tr><td><code>src_atop</code></td><td>9</td><td></td></tr>
<tr><td><code>multiply</code></td><td>14</td><td></td></tr>
<tr><td><code>screen</code></td><td>15</td><td></td></tr>
</table>
         */
        public static int backgroundTintMode=0x7f0100e6;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int barLength=0x7f01002d;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int borderlessButtonStyle=0x7f01009d;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int buttonBarButtonStyle=0x7f01009a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int buttonBarNegativeButtonStyle=0x7f0100c7;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int buttonBarNeutralButtonStyle=0x7f0100c8;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int buttonBarPositiveButtonStyle=0x7f0100c6;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int buttonBarStyle=0x7f010099;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int buttonPanelSideLayout=0x7f01001f;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int buttonStyle=0x7f0100ca;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int buttonStyleSmall=0x7f0100cb;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int buttonTint=0x7f010025;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>src_over</code></td><td>3</td><td></td></tr>
<tr><td><code>src_in</code></td><td>5</td><td></td></tr>
<tr><td><code>src_atop</code></td><td>9</td><td></td></tr>
<tr><td><code>multiply</code></td><td>14</td><td></td></tr>
<tr><td><code>screen</code></td><td>15</td><td></td></tr>
</table>
         */
        public static int buttonTintMode=0x7f010026;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int checkboxStyle=0x7f0100cc;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int checkedTextViewStyle=0x7f0100cd;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int closeIcon=0x7f010059;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int closeItemLayout=0x7f01001c;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int collapseContentDescription=0x7f0100dc;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int collapseIcon=0x7f0100db;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int color=0x7f010027;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int colorAccent=0x7f0100ba;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int colorButtonNormal=0x7f0100be;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int colorControlActivated=0x7f0100bc;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int colorControlHighlight=0x7f0100bd;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int colorControlNormal=0x7f0100bb;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int colorPrimary=0x7f0100b8;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int colorPrimaryDark=0x7f0100b9;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int colorSwitchThumbNormal=0x7f0100bf;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int commitIcon=0x7f01005e;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int contentInsetEnd=0x7f010017;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int contentInsetLeft=0x7f010018;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int contentInsetRight=0x7f010019;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int contentInsetStart=0x7f010016;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int controlBackground=0x7f0100c0;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int customNavigationLayout=0x7f01000f;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int defaultQueryHint=0x7f010058;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int dialogPreferredPadding=0x7f010092;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int dialogTheme=0x7f010091;
        /** <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>0</td><td></td></tr>
<tr><td><code>useLogo</code></td><td>0x1</td><td></td></tr>
<tr><td><code>showHome</code></td><td>0x2</td><td></td></tr>
<tr><td><code>homeAsUp</code></td><td>0x4</td><td></td></tr>
<tr><td><code>showTitle</code></td><td>0x8</td><td></td></tr>
<tr><td><code>showCustom</code></td><td>0x10</td><td></td></tr>
<tr><td><code>disableHome</code></td><td>0x20</td><td></td></tr>
</table>
         */
        public static int displayOptions=0x7f010005;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int divider=0x7f01000b;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int dividerHorizontal=0x7f01009f;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int dividerPadding=0x7f010049;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int dividerVertical=0x7f01009e;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int drawableSize=0x7f010029;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int drawerArrowStyle=0x7f010000;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int dropDownListViewStyle=0x7f0100b0;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int dropdownListPreferredItemHeight=0x7f010095;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int editTextBackground=0x7f0100a6;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static int editTextColor=0x7f0100a5;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int editTextStyle=0x7f0100ce;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int elevation=0x7f01001a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int expandActivityOverflowButtonDrawable=0x7f01001e;
        /** <p>Must be an integer value, such as "<code>100</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int fadeDuration=0x7f01002f;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int failureImage=0x7f010035;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
         */
        public static int failureImageScaleType=0x7f010036;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int gapBetweenBars=0x7f01002a;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int goIcon=0x7f01005a;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int height=0x7f010001;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int hideOnContentScroll=0x7f010015;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int homeAsUpIndicator=0x7f010097;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int homeLayout=0x7f010010;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int icon=0x7f010009;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int iconifiedByDefault=0x7f010056;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int indeterminateProgressStyle=0x7f010012;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int initialActivityCount=0x7f01001d;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int isLightTheme=0x7f010002;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int itemPadding=0x7f010014;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int layout=0x7f010055;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int layoutManager=0x7f010051;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int listChoiceBackgroundIndicator=0x7f0100b7;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int listDividerAlertDialog=0x7f010093;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int listItemLayout=0x7f010023;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int listLayout=0x7f010020;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int listPopupWindowStyle=0x7f0100b1;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int listPreferredItemHeight=0x7f0100ab;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int listPreferredItemHeightLarge=0x7f0100ad;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int listPreferredItemHeightSmall=0x7f0100ac;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int listPreferredItemPaddingLeft=0x7f0100ae;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int listPreferredItemPaddingRight=0x7f0100af;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int logo=0x7f01000a;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int logoDescription=0x7f0100df;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int maxButtonHeight=0x7f0100da;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int measureWithLargestChild=0x7f010047;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int multiChoiceItemLayout=0x7f010021;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int navigationContentDescription=0x7f0100de;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int navigationIcon=0x7f0100dd;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>normal</code></td><td>0</td><td></td></tr>
<tr><td><code>listMode</code></td><td>1</td><td></td></tr>
<tr><td><code>tabMode</code></td><td>2</td><td></td></tr>
</table>
         */
        public static int navigationMode=0x7f010004;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int overlapAnchor=0x7f01004f;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int overlayImage=0x7f01003c;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int paddingEnd=0x7f0100e3;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int paddingStart=0x7f0100e2;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int panelBackground=0x7f0100b4;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int panelMenuListTheme=0x7f0100b6;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int panelMenuListWidth=0x7f0100b5;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int placeholderImage=0x7f010031;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
         */
        public static int placeholderImageScaleType=0x7f010032;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int popupMenuStyle=0x7f0100a3;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int popupTheme=0x7f01001b;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int popupWindowStyle=0x7f0100a4;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int preserveIconSpacing=0x7f01004e;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int pressedStateOverlayImage=0x7f01003d;
        /** <p>Must be an integer value, such as "<code>100</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int progressBarAutoRotateInterval=0x7f010039;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int progressBarImage=0x7f010037;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
         */
        public static int progressBarImageScaleType=0x7f010038;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int progressBarPadding=0x7f010013;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int progressBarStyle=0x7f010011;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int queryBackground=0x7f010060;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int queryHint=0x7f010057;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int radioButtonStyle=0x7f0100cf;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int ratingBarStyle=0x7f0100d0;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int retryImage=0x7f010033;
        /** <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
         */
        public static int retryImageScaleType=0x7f010034;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int reverseLayout=0x7f010053;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int roundAsCircle=0x7f01003e;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int roundBottomLeft=0x7f010043;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int roundBottomRight=0x7f010042;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int roundTopLeft=0x7f010040;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int roundTopRight=0x7f010041;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int roundWithOverlayColor=0x7f010044;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int roundedCornerRadius=0x7f01003f;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int roundingBorderColor=0x7f010046;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int roundingBorderWidth=0x7f010045;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int searchHintIcon=0x7f01005c;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int searchIcon=0x7f01005b;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int searchViewStyle=0x7f0100aa;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int selectableItemBackground=0x7f01009b;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int selectableItemBackgroundBorderless=0x7f01009c;
        /** <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>never</code></td><td>0</td><td></td></tr>
<tr><td><code>ifRoom</code></td><td>1</td><td></td></tr>
<tr><td><code>always</code></td><td>2</td><td></td></tr>
<tr><td><code>withText</code></td><td>4</td><td></td></tr>
<tr><td><code>collapseActionView</code></td><td>8</td><td></td></tr>
</table>
         */
        public static int showAsAction=0x7f01004a;
        /** <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>0</td><td></td></tr>
<tr><td><code>beginning</code></td><td>1</td><td></td></tr>
<tr><td><code>middle</code></td><td>2</td><td></td></tr>
<tr><td><code>end</code></td><td>4</td><td></td></tr>
</table>
         */
        public static int showDividers=0x7f010048;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int showText=0x7f010068;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int singleChoiceItemLayout=0x7f010022;
        /** <p>Must be an integer value, such as "<code>100</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int spanCount=0x7f010052;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int spinBars=0x7f010028;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int spinnerDropDownItemStyle=0x7f010096;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int spinnerStyle=0x7f0100d1;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int splitTrack=0x7f010067;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int stackFromEnd=0x7f010054;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int state_above_anchor=0x7f010050;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int submitBackground=0x7f010061;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int subtitle=0x7f010006;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int subtitleTextAppearance=0x7f0100d4;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int subtitleTextColor=0x7f0100e1;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int subtitleTextStyle=0x7f010008;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int suggestionRowLayout=0x7f01005f;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int switchMinWidth=0x7f010065;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int switchPadding=0x7f010066;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int switchStyle=0x7f0100d2;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int switchTextAppearance=0x7f010064;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a boolean value, either "<code>true</code>" or "<code>false</code>".
         */
        public static int textAllCaps=0x7f010024;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int textAppearanceLargePopupMenu=0x7f01008f;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int textAppearanceListItem=0x7f0100b2;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int textAppearanceListItemSmall=0x7f0100b3;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int textAppearanceSearchResultSubtitle=0x7f0100a8;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int textAppearanceSearchResultTitle=0x7f0100a7;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int textAppearanceSmallPopupMenu=0x7f010090;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static int textColorAlertDialogListItem=0x7f0100c5;
        /** <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
         */
        public static int textColorSearchUrl=0x7f0100a9;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int theme=0x7f0100e4;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int thickness=0x7f01002e;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int thumbTextPadding=0x7f010063;
        /** <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int title=0x7f010003;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int titleMarginBottom=0x7f0100d9;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int titleMarginEnd=0x7f0100d7;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int titleMarginStart=0x7f0100d6;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int titleMarginTop=0x7f0100d8;
        /** <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int titleMargins=0x7f0100d5;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int titleTextAppearance=0x7f0100d3;
        /** <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int titleTextColor=0x7f0100e0;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int titleTextStyle=0x7f010007;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int toolbarNavigationButtonStyle=0x7f0100a2;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int toolbarStyle=0x7f0100a1;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int track=0x7f010062;
        /** <p>Must be a floating point value, such as "<code>1.2</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int viewAspectRatio=0x7f010030;
        /** <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
         */
        public static int voiceIcon=0x7f01005d;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int windowActionBar=0x7f010069;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int windowActionBarOverlay=0x7f01006b;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int windowActionModeOverlay=0x7f01006c;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int windowFixedHeightMajor=0x7f010070;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int windowFixedHeightMinor=0x7f01006e;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int windowFixedWidthMajor=0x7f01006d;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int windowFixedWidthMinor=0x7f01006f;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int windowMinWidthMajor=0x7f010071;
        /** <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int windowMinWidthMinor=0x7f010072;
        /** <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
         */
        public static int windowNoTitle=0x7f01006a;
    }
    public static final class bool {
        public static int abc_action_bar_embed_tabs=0x7f090002;
        public static int abc_action_bar_embed_tabs_pre_jb=0x7f090000;
        public static int abc_action_bar_expanded_action_views_exclusive=0x7f090003;
        public static int abc_config_actionMenuItemAllCaps=0x7f090004;
        public static int abc_config_allowActionMenuItemTextWithIcon=0x7f090001;
        public static int abc_config_closeDialogWhenTouchOutside=0x7f090005;
        public static int abc_config_showMenuShortcutsWhenKeyboardPresent=0x7f090006;
    }
    public static final class color {
        public static int abc_background_cache_hint_selector_material_dark=0x7f0b003b;
        public static int abc_background_cache_hint_selector_material_light=0x7f0b003c;
        public static int abc_color_highlight_material=0x7f0b003d;
        public static int abc_input_method_navigation_guard=0x7f0b0000;
        public static int abc_primary_text_disable_only_material_dark=0x7f0b003e;
        public static int abc_primary_text_disable_only_material_light=0x7f0b003f;
        public static int abc_primary_text_material_dark=0x7f0b0040;
        public static int abc_primary_text_material_light=0x7f0b0041;
        public static int abc_search_url_text=0x7f0b0042;
        public static int abc_search_url_text_normal=0x7f0b0001;
        public static int abc_search_url_text_pressed=0x7f0b0002;
        public static int abc_search_url_text_selected=0x7f0b0003;
        public static int abc_secondary_text_material_dark=0x7f0b0043;
        public static int abc_secondary_text_material_light=0x7f0b0044;
        public static int accent_material_dark=0x7f0b0004;
        public static int accent_material_light=0x7f0b0005;
        public static int background_floating_material_dark=0x7f0b0006;
        public static int background_floating_material_light=0x7f0b0007;
        public static int background_material_dark=0x7f0b0008;
        public static int background_material_light=0x7f0b0009;
        public static int bright_foreground_disabled_material_dark=0x7f0b000a;
        public static int bright_foreground_disabled_material_light=0x7f0b000b;
        public static int bright_foreground_inverse_material_dark=0x7f0b000c;
        public static int bright_foreground_inverse_material_light=0x7f0b000d;
        public static int bright_foreground_material_dark=0x7f0b000e;
        public static int bright_foreground_material_light=0x7f0b000f;
        public static int button_material_dark=0x7f0b0010;
        public static int button_material_light=0x7f0b0011;
        public static int catalyst_redbox_background=0x7f0b0012;
        public static int dim_foreground_disabled_material_dark=0x7f0b0013;
        public static int dim_foreground_disabled_material_light=0x7f0b0014;
        public static int dim_foreground_material_dark=0x7f0b0015;
        public static int dim_foreground_material_light=0x7f0b0016;
        public static int foreground_material_dark=0x7f0b0017;
        public static int foreground_material_light=0x7f0b0018;
        public static int highlighted_text_material_dark=0x7f0b0019;
        public static int highlighted_text_material_light=0x7f0b001a;
        public static int hint_foreground_material_dark=0x7f0b001b;
        public static int hint_foreground_material_light=0x7f0b001c;
        public static int material_blue_grey_800=0x7f0b001d;
        public static int material_blue_grey_900=0x7f0b001e;
        public static int material_blue_grey_950=0x7f0b001f;
        public static int material_deep_teal_200=0x7f0b0020;
        public static int material_deep_teal_500=0x7f0b0021;
        public static int material_grey_100=0x7f0b0022;
        public static int material_grey_300=0x7f0b0023;
        public static int material_grey_50=0x7f0b0024;
        public static int material_grey_600=0x7f0b0025;
        public static int material_grey_800=0x7f0b0026;
        public static int material_grey_850=0x7f0b0027;
        public static int material_grey_900=0x7f0b0028;
        public static int primary_dark_material_dark=0x7f0b0029;
        public static int primary_dark_material_light=0x7f0b002a;
        public static int primary_material_dark=0x7f0b002b;
        public static int primary_material_light=0x7f0b002c;
        public static int primary_text_default_material_dark=0x7f0b002d;
        public static int primary_text_default_material_light=0x7f0b002e;
        public static int primary_text_disabled_material_dark=0x7f0b002f;
        public static int primary_text_disabled_material_light=0x7f0b0030;
        public static int ripple_material_dark=0x7f0b0031;
        public static int ripple_material_light=0x7f0b0032;
        public static int secondary_text_default_material_dark=0x7f0b0033;
        public static int secondary_text_default_material_light=0x7f0b0034;
        public static int secondary_text_disabled_material_dark=0x7f0b0035;
        public static int secondary_text_disabled_material_light=0x7f0b0036;
        public static int switch_thumb_disabled_material_dark=0x7f0b0037;
        public static int switch_thumb_disabled_material_light=0x7f0b0038;
        public static int switch_thumb_material_dark=0x7f0b0045;
        public static int switch_thumb_material_light=0x7f0b0046;
        public static int switch_thumb_normal_material_dark=0x7f0b0039;
        public static int switch_thumb_normal_material_light=0x7f0b003a;
    }
    public static final class dimen {
        public static int abc_action_bar_content_inset_material=0x7f07000b;
        public static int abc_action_bar_default_height_material=0x7f070001;
        public static int abc_action_bar_default_padding_end_material=0x7f07000c;
        public static int abc_action_bar_default_padding_start_material=0x7f07000d;
        public static int abc_action_bar_icon_vertical_padding_material=0x7f07000f;
        public static int abc_action_bar_overflow_padding_end_material=0x7f070010;
        public static int abc_action_bar_overflow_padding_start_material=0x7f070011;
        public static int abc_action_bar_progress_bar_size=0x7f070002;
        public static int abc_action_bar_stacked_max_height=0x7f070012;
        public static int abc_action_bar_stacked_tab_max_width=0x7f070013;
        public static int abc_action_bar_subtitle_bottom_margin_material=0x7f070014;
        public static int abc_action_bar_subtitle_top_margin_material=0x7f070015;
        public static int abc_action_button_min_height_material=0x7f070016;
        public static int abc_action_button_min_width_material=0x7f070017;
        public static int abc_action_button_min_width_overflow_material=0x7f070018;
        public static int abc_alert_dialog_button_bar_height=0x7f070000;
        public static int abc_button_inset_horizontal_material=0x7f070019;
        public static int abc_button_inset_vertical_material=0x7f07001a;
        public static int abc_button_padding_horizontal_material=0x7f07001b;
        public static int abc_button_padding_vertical_material=0x7f07001c;
        public static int abc_config_prefDialogWidth=0x7f070005;
        public static int abc_control_corner_material=0x7f07001d;
        public static int abc_control_inset_material=0x7f07001e;
        public static int abc_control_padding_material=0x7f07001f;
        public static int abc_dialog_list_padding_vertical_material=0x7f070020;
        public static int abc_dialog_min_width_major=0x7f070021;
        public static int abc_dialog_min_width_minor=0x7f070022;
        public static int abc_dialog_padding_material=0x7f070023;
        public static int abc_dialog_padding_top_material=0x7f070024;
        public static int abc_disabled_alpha_material_dark=0x7f070025;
        public static int abc_disabled_alpha_material_light=0x7f070026;
        public static int abc_dropdownitem_icon_width=0x7f070027;
        public static int abc_dropdownitem_text_padding_left=0x7f070028;
        public static int abc_dropdownitem_text_padding_right=0x7f070029;
        public static int abc_edit_text_inset_bottom_material=0x7f07002a;
        public static int abc_edit_text_inset_horizontal_material=0x7f07002b;
        public static int abc_edit_text_inset_top_material=0x7f07002c;
        public static int abc_floating_window_z=0x7f07002d;
        public static int abc_list_item_padding_horizontal_material=0x7f07002e;
        public static int abc_panel_menu_list_width=0x7f07002f;
        public static int abc_search_view_preferred_width=0x7f070030;
        public static int abc_search_view_text_min_width=0x7f070006;
        public static int abc_switch_padding=0x7f07000e;
        public static int abc_text_size_body_1_material=0x7f070031;
        public static int abc_text_size_body_2_material=0x7f070032;
        public static int abc_text_size_button_material=0x7f070033;
        public static int abc_text_size_caption_material=0x7f070034;
        public static int abc_text_size_display_1_material=0x7f070035;
        public static int abc_text_size_display_2_material=0x7f070036;
        public static int abc_text_size_display_3_material=0x7f070037;
        public static int abc_text_size_display_4_material=0x7f070038;
        public static int abc_text_size_headline_material=0x7f070039;
        public static int abc_text_size_large_material=0x7f07003a;
        public static int abc_text_size_medium_material=0x7f07003b;
        public static int abc_text_size_menu_material=0x7f07003c;
        public static int abc_text_size_small_material=0x7f07003d;
        public static int abc_text_size_subhead_material=0x7f07003e;
        public static int abc_text_size_subtitle_material_toolbar=0x7f070003;
        public static int abc_text_size_title_material=0x7f07003f;
        public static int abc_text_size_title_material_toolbar=0x7f070004;
        public static int dialog_fixed_height_major=0x7f070007;
        public static int dialog_fixed_height_minor=0x7f070008;
        public static int dialog_fixed_width_major=0x7f070009;
        public static int dialog_fixed_width_minor=0x7f07000a;
        public static int disabled_alpha_material_dark=0x7f070040;
        public static int disabled_alpha_material_light=0x7f070041;
        public static int highlight_alpha_material_colored=0x7f070042;
        public static int highlight_alpha_material_dark=0x7f070043;
        public static int highlight_alpha_material_light=0x7f070044;
        public static int item_touch_helper_max_drag_scroll_per_frame=0x7f070045;
        public static int notification_large_icon_height=0x7f070046;
        public static int notification_large_icon_width=0x7f070047;
        public static int notification_subtext_size=0x7f070048;
    }
    public static final class drawable {
        public static int abc_ab_share_pack_mtrl_alpha=0x7f020000;
        public static int abc_action_bar_item_background_material=0x7f020001;
        public static int abc_btn_borderless_material=0x7f020002;
        public static int abc_btn_check_material=0x7f020003;
        public static int abc_btn_check_to_on_mtrl_000=0x7f020004;
        public static int abc_btn_check_to_on_mtrl_015=0x7f020005;
        public static int abc_btn_colored_material=0x7f020006;
        public static int abc_btn_default_mtrl_shape=0x7f020007;
        public static int abc_btn_radio_material=0x7f020008;
        public static int abc_btn_radio_to_on_mtrl_000=0x7f020009;
        public static int abc_btn_radio_to_on_mtrl_015=0x7f02000a;
        public static int abc_btn_rating_star_off_mtrl_alpha=0x7f02000b;
        public static int abc_btn_rating_star_on_mtrl_alpha=0x7f02000c;
        public static int abc_btn_switch_to_on_mtrl_00001=0x7f02000d;
        public static int abc_btn_switch_to_on_mtrl_00012=0x7f02000e;
        public static int abc_cab_background_internal_bg=0x7f02000f;
        public static int abc_cab_background_top_material=0x7f020010;
        public static int abc_cab_background_top_mtrl_alpha=0x7f020011;
        public static int abc_control_background_material=0x7f020012;
        public static int abc_dialog_material_background_dark=0x7f020013;
        public static int abc_dialog_material_background_light=0x7f020014;
        public static int abc_edit_text_material=0x7f020015;
        public static int abc_ic_ab_back_mtrl_am_alpha=0x7f020016;
        public static int abc_ic_clear_mtrl_alpha=0x7f020017;
        public static int abc_ic_commit_search_api_mtrl_alpha=0x7f020018;
        public static int abc_ic_go_search_api_mtrl_alpha=0x7f020019;
        public static int abc_ic_menu_copy_mtrl_am_alpha=0x7f02001a;
        public static int abc_ic_menu_cut_mtrl_alpha=0x7f02001b;
        public static int abc_ic_menu_moreoverflow_mtrl_alpha=0x7f02001c;
        public static int abc_ic_menu_paste_mtrl_am_alpha=0x7f02001d;
        public static int abc_ic_menu_selectall_mtrl_alpha=0x7f02001e;
        public static int abc_ic_menu_share_mtrl_alpha=0x7f02001f;
        public static int abc_ic_search_api_mtrl_alpha=0x7f020020;
        public static int abc_ic_voice_search_api_mtrl_alpha=0x7f020021;
        public static int abc_item_background_holo_dark=0x7f020022;
        public static int abc_item_background_holo_light=0x7f020023;
        public static int abc_list_divider_mtrl_alpha=0x7f020024;
        public static int abc_list_focused_holo=0x7f020025;
        public static int abc_list_longpressed_holo=0x7f020026;
        public static int abc_list_pressed_holo_dark=0x7f020027;
        public static int abc_list_pressed_holo_light=0x7f020028;
        public static int abc_list_selector_background_transition_holo_dark=0x7f020029;
        public static int abc_list_selector_background_transition_holo_light=0x7f02002a;
        public static int abc_list_selector_disabled_holo_dark=0x7f02002b;
        public static int abc_list_selector_disabled_holo_light=0x7f02002c;
        public static int abc_list_selector_holo_dark=0x7f02002d;
        public static int abc_list_selector_holo_light=0x7f02002e;
        public static int abc_menu_hardkey_panel_mtrl_mult=0x7f02002f;
        public static int abc_popup_background_mtrl_mult=0x7f020030;
        public static int abc_ratingbar_full_material=0x7f020031;
        public static int abc_spinner_mtrl_am_alpha=0x7f020032;
        public static int abc_spinner_textfield_background_material=0x7f020033;
        public static int abc_switch_thumb_material=0x7f020034;
        public static int abc_switch_track_mtrl_alpha=0x7f020035;
        public static int abc_tab_indicator_material=0x7f020036;
        public static int abc_tab_indicator_mtrl_alpha=0x7f020037;
        public static int abc_text_cursor_material=0x7f020038;
        public static int abc_textfield_activated_mtrl_alpha=0x7f020039;
        public static int abc_textfield_default_mtrl_alpha=0x7f02003a;
        public static int abc_textfield_search_activated_mtrl_alpha=0x7f02003b;
        public static int abc_textfield_search_default_mtrl_alpha=0x7f02003c;
        public static int abc_textfield_search_material=0x7f02003d;
        public static int notification_template_icon_bg=0x7f02003e;
    }
    public static final class id {
        public static int action0=0x7f0c0057;
        public static int action_bar=0x7f0c0047;
        public static int action_bar_activity_content=0x7f0c0000;
        public static int action_bar_container=0x7f0c0046;
        public static int action_bar_root=0x7f0c0042;
        public static int action_bar_spinner=0x7f0c0001;
        public static int action_bar_subtitle=0x7f0c002b;
        public static int action_bar_title=0x7f0c002a;
        public static int action_context_bar=0x7f0c0048;
        public static int action_divider=0x7f0c005b;
        public static int action_menu_divider=0x7f0c0002;
        public static int action_menu_presenter=0x7f0c0003;
        public static int action_mode_bar=0x7f0c0044;
        public static int action_mode_bar_stub=0x7f0c0043;
        public static int action_mode_close_button=0x7f0c002c;
        public static int activity_chooser_view_content=0x7f0c002d;
        public static int alertTitle=0x7f0c0037;
        public static int always=0x7f0c0024;
        public static int beginning=0x7f0c0021;
        public static int buttonPanel=0x7f0c003d;
        public static int cancel_action=0x7f0c0058;
        public static int catalyst_redbox_title=0x7f0c0066;
        public static int center=0x7f0c0019;
        public static int centerCrop=0x7f0c001a;
        public static int centerInside=0x7f0c001b;
        public static int checkbox=0x7f0c003f;
        public static int chronometer=0x7f0c005e;
        public static int collapseActionView=0x7f0c0025;
        public static int contentPanel=0x7f0c0038;
        public static int custom=0x7f0c003c;
        public static int customPanel=0x7f0c003b;
        public static int decor_content_parent=0x7f0c0045;
        public static int default_activity_button=0x7f0c0030;
        public static int disableHome=0x7f0c000d;
        public static int edit_query=0x7f0c0049;
        public static int end=0x7f0c0022;
        public static int end_padder=0x7f0c0063;
        public static int expand_activities_button=0x7f0c002e;
        public static int expanded_menu=0x7f0c003e;
        public static int fitCenter=0x7f0c001c;
        public static int fitEnd=0x7f0c001d;
        public static int fitStart=0x7f0c001e;
        public static int fitXY=0x7f0c001f;
        public static int focusCrop=0x7f0c0020;
        public static int fps_text=0x7f0c0056;
        public static int home=0x7f0c0004;
        public static int homeAsUp=0x7f0c000e;
        public static int icon=0x7f0c0032;
        public static int ifRoom=0x7f0c0026;
        public static int image=0x7f0c002f;
        public static int info=0x7f0c0062;
        public static int item_touch_helper_previous_elevation=0x7f0c0005;
        public static int line1=0x7f0c005c;
        public static int line3=0x7f0c0060;
        public static int listMode=0x7f0c000a;
        public static int list_item=0x7f0c0031;
        public static int media_actions=0x7f0c005a;
        public static int middle=0x7f0c0023;
        public static int multiply=0x7f0c0014;
        public static int never=0x7f0c0027;
        public static int none=0x7f0c000f;
        public static int normal=0x7f0c000b;
        public static int parentPanel=0x7f0c0034;
        public static int progress_circular=0x7f0c0006;
        public static int progress_horizontal=0x7f0c0007;
        public static int radio=0x7f0c0041;
        public static int rn_frame_file=0x7f0c0065;
        public static int rn_frame_method=0x7f0c0064;
        public static int rn_redbox_reloadjs=0x7f0c0068;
        public static int rn_redbox_stack=0x7f0c0067;
        public static int screen=0x7f0c0015;
        public static int scrollView=0x7f0c0039;
        public static int search_badge=0x7f0c004b;
        public static int search_bar=0x7f0c004a;
        public static int search_button=0x7f0c004c;
        public static int search_close_btn=0x7f0c0051;
        public static int search_edit_frame=0x7f0c004d;
        public static int search_go_btn=0x7f0c0053;
        public static int search_mag_icon=0x7f0c004e;
        public static int search_plate=0x7f0c004f;
        public static int search_src_text=0x7f0c0050;
        public static int search_voice_btn=0x7f0c0054;
        public static int select_dialog_listview=0x7f0c0055;
        public static int shortcut=0x7f0c0040;
        public static int showCustom=0x7f0c0010;
        public static int showHome=0x7f0c0011;
        public static int showTitle=0x7f0c0012;
        public static int split_action_bar=0x7f0c0008;
        public static int src_atop=0x7f0c0016;
        public static int src_in=0x7f0c0017;
        public static int src_over=0x7f0c0018;
        public static int status_bar_latest_event_content=0x7f0c0059;
        public static int submit_area=0x7f0c0052;
        public static int tabMode=0x7f0c000c;
        public static int text=0x7f0c0061;
        public static int text2=0x7f0c005f;
        public static int textSpacerNoButtons=0x7f0c003a;
        public static int time=0x7f0c005d;
        public static int title=0x7f0c0033;
        public static int title_template=0x7f0c0036;
        public static int topPanel=0x7f0c0035;
        public static int up=0x7f0c0009;
        public static int useLogo=0x7f0c0013;
        public static int withText=0x7f0c0028;
        public static int wrap_content=0x7f0c0029;
    }
    public static final class integer {
        public static int abc_config_activityDefaultDur=0x7f0a0001;
        public static int abc_config_activityShortDur=0x7f0a0002;
        public static int abc_max_action_buttons=0x7f0a0000;
        public static int cancel_button_image_alpha=0x7f0a0003;
        public static int status_bar_notification_info_maxnum=0x7f0a0004;
    }
    public static final class layout {
        public static int abc_action_bar_title_item=0x7f030000;
        public static int abc_action_bar_up_container=0x7f030001;
        public static int abc_action_bar_view_list_nav_layout=0x7f030002;
        public static int abc_action_menu_item_layout=0x7f030003;
        public static int abc_action_menu_layout=0x7f030004;
        public static int abc_action_mode_bar=0x7f030005;
        public static int abc_action_mode_close_item_material=0x7f030006;
        public static int abc_activity_chooser_view=0x7f030007;
        public static int abc_activity_chooser_view_list_item=0x7f030008;
        public static int abc_alert_dialog_material=0x7f030009;
        public static int abc_dialog_title_material=0x7f03000a;
        public static int abc_expanded_menu_layout=0x7f03000b;
        public static int abc_list_menu_item_checkbox=0x7f03000c;
        public static int abc_list_menu_item_icon=0x7f03000d;
        public static int abc_list_menu_item_layout=0x7f03000e;
        public static int abc_list_menu_item_radio=0x7f03000f;
        public static int abc_popup_menu_item_layout=0x7f030010;
        public static int abc_screen_content_include=0x7f030011;
        public static int abc_screen_simple=0x7f030012;
        public static int abc_screen_simple_overlay_action_mode=0x7f030013;
        public static int abc_screen_toolbar=0x7f030014;
        public static int abc_search_dropdown_item_icons_2line=0x7f030015;
        public static int abc_search_view=0x7f030016;
        public static int abc_select_dialog_material=0x7f030017;
        public static int fps_view=0x7f030018;
        public static int notification_media_action=0x7f030019;
        public static int notification_media_cancel_action=0x7f03001a;
        public static int notification_template_big_media=0x7f03001b;
        public static int notification_template_big_media_narrow=0x7f03001c;
        public static int notification_template_lines=0x7f03001d;
        public static int notification_template_media=0x7f03001e;
        public static int notification_template_part_chronometer=0x7f03001f;
        public static int notification_template_part_time=0x7f030020;
        public static int redbox_item_frame=0x7f030021;
        public static int redbox_item_title=0x7f030022;
        public static int redbox_view=0x7f030023;
        public static int select_dialog_item_material=0x7f030024;
        public static int select_dialog_multichoice_material=0x7f030025;
        public static int select_dialog_singlechoice_material=0x7f030026;
        public static int support_simple_spinner_dropdown_item=0x7f030027;
    }
    public static final class string {
        public static int abc_action_bar_home_description=0x7f060000;
        public static int abc_action_bar_home_description_format=0x7f060001;
        public static int abc_action_bar_home_subtitle_description_format=0x7f060002;
        public static int abc_action_bar_up_description=0x7f060003;
        public static int abc_action_menu_overflow_description=0x7f060004;
        public static int abc_action_mode_done=0x7f060005;
        public static int abc_activity_chooser_view_see_all=0x7f060006;
        public static int abc_activitychooserview_choose_application=0x7f060007;
        public static int abc_search_hint=0x7f060008;
        public static int abc_searchview_description_clear=0x7f060009;
        public static int abc_searchview_description_query=0x7f06000a;
        public static int abc_searchview_description_search=0x7f06000b;
        public static int abc_searchview_description_submit=0x7f06000c;
        public static int abc_searchview_description_voice=0x7f06000d;
        public static int abc_shareactionprovider_share_with=0x7f06000e;
        public static int abc_shareactionprovider_share_with_application=0x7f06000f;
        public static int abc_toolbar_collapse_description=0x7f060010;
        public static int catalyst_debugjs=0x7f060012;
        public static int catalyst_debugjs_off=0x7f06001a;
        public static int catalyst_element_inspector=0x7f060013;
        public static int catalyst_element_inspector_off=0x7f06001b;
        public static int catalyst_hot_module_replacement=0x7f06001c;
        public static int catalyst_hot_module_replacement_off=0x7f06001d;
        public static int catalyst_jsload_error=0x7f060014;
        public static int catalyst_jsload_message=0x7f060015;
        public static int catalyst_jsload_title=0x7f060016;
        public static int catalyst_live_reload=0x7f06001e;
        public static int catalyst_live_reload_off=0x7f06001f;
        public static int catalyst_perf_monitor=0x7f060020;
        public static int catalyst_perf_monitor_off=0x7f060021;
        public static int catalyst_reloadjs=0x7f060017;
        public static int catalyst_remotedbg_error=0x7f060022;
        public static int catalyst_remotedbg_message=0x7f060023;
        public static int catalyst_settings=0x7f060018;
        public static int catalyst_settings_title=0x7f060019;
        public static int catalyst_start_profile=0x7f060024;
        public static int catalyst_stop_profile=0x7f060025;
        public static int status_bar_notification_info_overflow=0x7f060011;
    }
    public static final class style {
        public static int AlertDialog_AppCompat=0x7f08007a;
        public static int AlertDialog_AppCompat_Light=0x7f08007b;
        public static int Animation_AppCompat_Dialog=0x7f08007c;
        public static int Animation_AppCompat_DropDownUp=0x7f08007d;
        public static int Animation_Catalyst_RedBox=0x7f08007e;
        public static int Base_AlertDialog_AppCompat=0x7f08007f;
        public static int Base_AlertDialog_AppCompat_Light=0x7f080080;
        public static int Base_Animation_AppCompat_Dialog=0x7f080081;
        public static int Base_Animation_AppCompat_DropDownUp=0x7f080082;
        public static int Base_DialogWindowTitle_AppCompat=0x7f080083;
        public static int Base_DialogWindowTitleBackground_AppCompat=0x7f080084;
        public static int Base_TextAppearance_AppCompat=0x7f08002d;
        public static int Base_TextAppearance_AppCompat_Body1=0x7f08002e;
        public static int Base_TextAppearance_AppCompat_Body2=0x7f08002f;
        public static int Base_TextAppearance_AppCompat_Button=0x7f080018;
        public static int Base_TextAppearance_AppCompat_Caption=0x7f080030;
        public static int Base_TextAppearance_AppCompat_Display1=0x7f080031;
        public static int Base_TextAppearance_AppCompat_Display2=0x7f080032;
        public static int Base_TextAppearance_AppCompat_Display3=0x7f080033;
        public static int Base_TextAppearance_AppCompat_Display4=0x7f080034;
        public static int Base_TextAppearance_AppCompat_Headline=0x7f080035;
        public static int Base_TextAppearance_AppCompat_Inverse=0x7f080003;
        public static int Base_TextAppearance_AppCompat_Large=0x7f080036;
        public static int Base_TextAppearance_AppCompat_Large_Inverse=0x7f080004;
        public static int Base_TextAppearance_AppCompat_Light_Widget_PopupMenu_Large=0x7f080037;
        public static int Base_TextAppearance_AppCompat_Light_Widget_PopupMenu_Small=0x7f080038;
        public static int Base_TextAppearance_AppCompat_Medium=0x7f080039;
        public static int Base_TextAppearance_AppCompat_Medium_Inverse=0x7f080005;
        public static int Base_TextAppearance_AppCompat_Menu=0x7f08003a;
        public static int Base_TextAppearance_AppCompat_SearchResult=0x7f080085;
        public static int Base_TextAppearance_AppCompat_SearchResult_Subtitle=0x7f08003b;
        public static int Base_TextAppearance_AppCompat_SearchResult_Title=0x7f08003c;
        public static int Base_TextAppearance_AppCompat_Small=0x7f08003d;
        public static int Base_TextAppearance_AppCompat_Small_Inverse=0x7f080006;
        public static int Base_TextAppearance_AppCompat_Subhead=0x7f08003e;
        public static int Base_TextAppearance_AppCompat_Subhead_Inverse=0x7f080007;
        public static int Base_TextAppearance_AppCompat_Title=0x7f08003f;
        public static int Base_TextAppearance_AppCompat_Title_Inverse=0x7f080008;
        public static int Base_TextAppearance_AppCompat_Widget_ActionBar_Menu=0x7f080040;
        public static int Base_TextAppearance_AppCompat_Widget_ActionBar_Subtitle=0x7f080041;
        public static int Base_TextAppearance_AppCompat_Widget_ActionBar_Subtitle_Inverse=0x7f080042;
        public static int Base_TextAppearance_AppCompat_Widget_ActionBar_Title=0x7f080043;
        public static int Base_TextAppearance_AppCompat_Widget_ActionBar_Title_Inverse=0x7f080044;
        public static int Base_TextAppearance_AppCompat_Widget_ActionMode_Subtitle=0x7f080045;
        public static int Base_TextAppearance_AppCompat_Widget_ActionMode_Title=0x7f080046;
        public static int Base_TextAppearance_AppCompat_Widget_Button=0x7f080047;
        public static int Base_TextAppearance_AppCompat_Widget_Button_Inverse=0x7f080076;
        public static int Base_TextAppearance_AppCompat_Widget_DropDownItem=0x7f080086;
        public static int Base_TextAppearance_AppCompat_Widget_PopupMenu_Large=0x7f080048;
        public static int Base_TextAppearance_AppCompat_Widget_PopupMenu_Small=0x7f080049;
        public static int Base_TextAppearance_AppCompat_Widget_Switch=0x7f08004a;
        public static int Base_TextAppearance_AppCompat_Widget_TextView_SpinnerItem=0x7f08004b;
        public static int Base_TextAppearance_Widget_AppCompat_ExpandedMenu_Item=0x7f080087;
        public static int Base_TextAppearance_Widget_AppCompat_Toolbar_Subtitle=0x7f08004c;
        public static int Base_TextAppearance_Widget_AppCompat_Toolbar_Title=0x7f08004d;
        public static int Base_Theme_AppCompat=0x7f08004e;
        public static int Base_Theme_AppCompat_CompactMenu=0x7f080088;
        public static int Base_Theme_AppCompat_Dialog=0x7f080009;
        public static int Base_Theme_AppCompat_Dialog_Alert=0x7f080089;
        public static int Base_Theme_AppCompat_Dialog_FixedSize=0x7f08008a;
        public static int Base_Theme_AppCompat_Dialog_MinWidth=0x7f08008b;
        public static int Base_Theme_AppCompat_DialogWhenLarge=0x7f080001;
        public static int Base_Theme_AppCompat_Light=0x7f08004f;
        public static int Base_Theme_AppCompat_Light_DarkActionBar=0x7f08008c;
        public static int Base_Theme_AppCompat_Light_Dialog=0x7f08000a;
        public static int Base_Theme_AppCompat_Light_Dialog_Alert=0x7f08008d;
        public static int Base_Theme_AppCompat_Light_Dialog_FixedSize=0x7f08008e;
        public static int Base_Theme_AppCompat_Light_Dialog_MinWidth=0x7f08008f;
        public static int Base_Theme_AppCompat_Light_DialogWhenLarge=0x7f080002;
        public static int Base_ThemeOverlay_AppCompat=0x7f080090;
        public static int Base_ThemeOverlay_AppCompat_ActionBar=0x7f080091;
        public static int Base_ThemeOverlay_AppCompat_Dark=0x7f080092;
        public static int Base_ThemeOverlay_AppCompat_Dark_ActionBar=0x7f080093;
        public static int Base_ThemeOverlay_AppCompat_Light=0x7f080094;
        public static int Base_V11_Theme_AppCompat_Dialog=0x7f08000b;
        public static int Base_V11_Theme_AppCompat_Light_Dialog=0x7f08000c;
        public static int Base_V12_Widget_AppCompat_AutoCompleteTextView=0x7f080014;
        public static int Base_V12_Widget_AppCompat_EditText=0x7f080015;
        public static int Base_V21_Theme_AppCompat=0x7f080050;
        public static int Base_V21_Theme_AppCompat_Dialog=0x7f080051;
        public static int Base_V21_Theme_AppCompat_Light=0x7f080052;
        public static int Base_V21_Theme_AppCompat_Light_Dialog=0x7f080053;
        public static int Base_V22_Theme_AppCompat=0x7f080074;
        public static int Base_V22_Theme_AppCompat_Light=0x7f080075;
        public static int Base_V23_Theme_AppCompat=0x7f080077;
        public static int Base_V23_Theme_AppCompat_Light=0x7f080078;
        public static int Base_V7_Theme_AppCompat=0x7f080095;
        public static int Base_V7_Theme_AppCompat_Dialog=0x7f080096;
        public static int Base_V7_Theme_AppCompat_Light=0x7f080097;
        public static int Base_V7_Theme_AppCompat_Light_Dialog=0x7f080098;
        public static int Base_V7_Widget_AppCompat_AutoCompleteTextView=0x7f080099;
        public static int Base_V7_Widget_AppCompat_EditText=0x7f08009a;
        public static int Base_Widget_AppCompat_ActionBar=0x7f08009b;
        public static int Base_Widget_AppCompat_ActionBar_Solid=0x7f08009c;
        public static int Base_Widget_AppCompat_ActionBar_TabBar=0x7f08009d;
        public static int Base_Widget_AppCompat_ActionBar_TabText=0x7f080054;
        public static int Base_Widget_AppCompat_ActionBar_TabView=0x7f080055;
        public static int Base_Widget_AppCompat_ActionButton=0x7f080056;
        public static int Base_Widget_AppCompat_ActionButton_CloseMode=0x7f080057;
        public static int Base_Widget_AppCompat_ActionButton_Overflow=0x7f080058;
        public static int Base_Widget_AppCompat_ActionMode=0x7f08009e;
        public static int Base_Widget_AppCompat_ActivityChooserView=0x7f08009f;
        public static int Base_Widget_AppCompat_AutoCompleteTextView=0x7f080016;
        public static int Base_Widget_AppCompat_Button=0x7f080059;
        public static int Base_Widget_AppCompat_Button_Borderless=0x7f08005a;
        public static int Base_Widget_AppCompat_Button_Borderless_Colored=0x7f08005b;
        public static int Base_Widget_AppCompat_Button_ButtonBar_AlertDialog=0x7f0800a0;
        public static int Base_Widget_AppCompat_Button_Colored=0x7f080079;
        public static int Base_Widget_AppCompat_Button_Small=0x7f08005c;
        public static int Base_Widget_AppCompat_ButtonBar=0x7f08005d;
        public static int Base_Widget_AppCompat_ButtonBar_AlertDialog=0x7f0800a1;
        public static int Base_Widget_AppCompat_CompoundButton_CheckBox=0x7f08005e;
        public static int Base_Widget_AppCompat_CompoundButton_RadioButton=0x7f08005f;
        public static int Base_Widget_AppCompat_CompoundButton_Switch=0x7f0800a2;
        public static int Base_Widget_AppCompat_DrawerArrowToggle=0x7f080000;
        public static int Base_Widget_AppCompat_DrawerArrowToggle_Common=0x7f0800a3;
        public static int Base_Widget_AppCompat_DropDownItem_Spinner=0x7f080060;
        public static int Base_Widget_AppCompat_EditText=0x7f080017;
        public static int Base_Widget_AppCompat_Light_ActionBar=0x7f0800a4;
        public static int Base_Widget_AppCompat_Light_ActionBar_Solid=0x7f0800a5;
        public static int Base_Widget_AppCompat_Light_ActionBar_TabBar=0x7f0800a6;
        public static int Base_Widget_AppCompat_Light_ActionBar_TabText=0x7f080061;
        public static int Base_Widget_AppCompat_Light_ActionBar_TabText_Inverse=0x7f080062;
        public static int Base_Widget_AppCompat_Light_ActionBar_TabView=0x7f080063;
        public static int Base_Widget_AppCompat_Light_PopupMenu=0x7f080064;
        public static int Base_Widget_AppCompat_Light_PopupMenu_Overflow=0x7f080065;
        public static int Base_Widget_AppCompat_ListPopupWindow=0x7f080066;
        public static int Base_Widget_AppCompat_ListView=0x7f080067;
        public static int Base_Widget_AppCompat_ListView_DropDown=0x7f080068;
        public static int Base_Widget_AppCompat_ListView_Menu=0x7f080069;
        public static int Base_Widget_AppCompat_PopupMenu=0x7f08006a;
        public static int Base_Widget_AppCompat_PopupMenu_Overflow=0x7f08006b;
        public static int Base_Widget_AppCompat_PopupWindow=0x7f0800a7;
        public static int Base_Widget_AppCompat_ProgressBar=0x7f08000d;
        public static int Base_Widget_AppCompat_ProgressBar_Horizontal=0x7f08000e;
        public static int Base_Widget_AppCompat_RatingBar=0x7f08006c;
        public static int Base_Widget_AppCompat_SearchView=0x7f0800a8;
        public static int Base_Widget_AppCompat_SearchView_ActionBar=0x7f0800a9;
        public static int Base_Widget_AppCompat_Spinner=0x7f08006d;
        public static int Base_Widget_AppCompat_Spinner_Underlined=0x7f08006e;
        public static int Base_Widget_AppCompat_TextView_SpinnerItem=0x7f08006f;
        public static int Base_Widget_AppCompat_Toolbar=0x7f0800aa;
        public static int Base_Widget_AppCompat_Toolbar_Button_Navigation=0x7f080070;
        public static int Platform_AppCompat=0x7f08000f;
        public static int Platform_AppCompat_Light=0x7f080010;
        public static int Platform_ThemeOverlay_AppCompat=0x7f080071;
        public static int Platform_ThemeOverlay_AppCompat_Dark=0x7f080072;
        public static int Platform_ThemeOverlay_AppCompat_Light=0x7f080073;
        public static int Platform_V11_AppCompat=0x7f080011;
        public static int Platform_V11_AppCompat_Light=0x7f080012;
        public static int Platform_V14_AppCompat=0x7f080019;
        public static int Platform_V14_AppCompat_Light=0x7f08001a;
        public static int Platform_Widget_AppCompat_Spinner=0x7f080013;
        public static int RtlOverlay_DialogWindowTitle_AppCompat=0x7f080020;
        public static int RtlOverlay_Widget_AppCompat_ActionBar_TitleItem=0x7f080021;
        public static int RtlOverlay_Widget_AppCompat_ActionButton_Overflow=0x7f080022;
        public static int RtlOverlay_Widget_AppCompat_DialogTitle_Icon=0x7f080023;
        public static int RtlOverlay_Widget_AppCompat_PopupMenuItem=0x7f080024;
        public static int RtlOverlay_Widget_AppCompat_PopupMenuItem_InternalGroup=0x7f080025;
        public static int RtlOverlay_Widget_AppCompat_PopupMenuItem_Text=0x7f080026;
        public static int RtlOverlay_Widget_AppCompat_Search_DropDown=0x7f080027;
        public static int RtlOverlay_Widget_AppCompat_Search_DropDown_Icon1=0x7f080028;
        public static int RtlOverlay_Widget_AppCompat_Search_DropDown_Icon2=0x7f080029;
        public static int RtlOverlay_Widget_AppCompat_Search_DropDown_Query=0x7f08002a;
        public static int RtlOverlay_Widget_AppCompat_Search_DropDown_Text=0x7f08002b;
        public static int RtlOverlay_Widget_AppCompat_SearchView_MagIcon=0x7f08002c;
        public static int TextAppearance_AppCompat=0x7f0800ab;
        public static int TextAppearance_AppCompat_Body1=0x7f0800ac;
        public static int TextAppearance_AppCompat_Body2=0x7f0800ad;
        public static int TextAppearance_AppCompat_Button=0x7f0800ae;
        public static int TextAppearance_AppCompat_Caption=0x7f0800af;
        public static int TextAppearance_AppCompat_Display1=0x7f0800b0;
        public static int TextAppearance_AppCompat_Display2=0x7f0800b1;
        public static int TextAppearance_AppCompat_Display3=0x7f0800b2;
        public static int TextAppearance_AppCompat_Display4=0x7f0800b3;
        public static int TextAppearance_AppCompat_Headline=0x7f0800b4;
        public static int TextAppearance_AppCompat_Inverse=0x7f0800b5;
        public static int TextAppearance_AppCompat_Large=0x7f0800b6;
        public static int TextAppearance_AppCompat_Large_Inverse=0x7f0800b7;
        public static int TextAppearance_AppCompat_Light_SearchResult_Subtitle=0x7f0800b8;
        public static int TextAppearance_AppCompat_Light_SearchResult_Title=0x7f0800b9;
        public static int TextAppearance_AppCompat_Light_Widget_PopupMenu_Large=0x7f0800ba;
        public static int TextAppearance_AppCompat_Light_Widget_PopupMenu_Small=0x7f0800bb;
        public static int TextAppearance_AppCompat_Medium=0x7f0800bc;
        public static int TextAppearance_AppCompat_Medium_Inverse=0x7f0800bd;
        public static int TextAppearance_AppCompat_Menu=0x7f0800be;
        public static int TextAppearance_AppCompat_SearchResult_Subtitle=0x7f0800bf;
        public static int TextAppearance_AppCompat_SearchResult_Title=0x7f0800c0;
        public static int TextAppearance_AppCompat_Small=0x7f0800c1;
        public static int TextAppearance_AppCompat_Small_Inverse=0x7f0800c2;
        public static int TextAppearance_AppCompat_Subhead=0x7f0800c3;
        public static int TextAppearance_AppCompat_Subhead_Inverse=0x7f0800c4;
        public static int TextAppearance_AppCompat_Title=0x7f0800c5;
        public static int TextAppearance_AppCompat_Title_Inverse=0x7f0800c6;
        public static int TextAppearance_AppCompat_Widget_ActionBar_Menu=0x7f0800c7;
        public static int TextAppearance_AppCompat_Widget_ActionBar_Subtitle=0x7f0800c8;
        public static int TextAppearance_AppCompat_Widget_ActionBar_Subtitle_Inverse=0x7f0800c9;
        public static int TextAppearance_AppCompat_Widget_ActionBar_Title=0x7f0800ca;
        public static int TextAppearance_AppCompat_Widget_ActionBar_Title_Inverse=0x7f0800cb;
        public static int TextAppearance_AppCompat_Widget_ActionMode_Subtitle=0x7f0800cc;
        public static int TextAppearance_AppCompat_Widget_ActionMode_Subtitle_Inverse=0x7f0800cd;
        public static int TextAppearance_AppCompat_Widget_ActionMode_Title=0x7f0800ce;
        public static int TextAppearance_AppCompat_Widget_ActionMode_Title_Inverse=0x7f0800cf;
        public static int TextAppearance_AppCompat_Widget_Button=0x7f0800d0;
        public static int TextAppearance_AppCompat_Widget_Button_Inverse=0x7f0800d1;
        public static int TextAppearance_AppCompat_Widget_DropDownItem=0x7f0800d2;
        public static int TextAppearance_AppCompat_Widget_PopupMenu_Large=0x7f0800d3;
        public static int TextAppearance_AppCompat_Widget_PopupMenu_Small=0x7f0800d4;
        public static int TextAppearance_AppCompat_Widget_Switch=0x7f0800d5;
        public static int TextAppearance_AppCompat_Widget_TextView_SpinnerItem=0x7f0800d6;
        public static int TextAppearance_StatusBar_EventContent=0x7f08001b;
        public static int TextAppearance_StatusBar_EventContent_Info=0x7f08001c;
        public static int TextAppearance_StatusBar_EventContent_Line2=0x7f08001d;
        public static int TextAppearance_StatusBar_EventContent_Time=0x7f08001e;
        public static int TextAppearance_StatusBar_EventContent_Title=0x7f08001f;
        public static int TextAppearance_Widget_AppCompat_ExpandedMenu_Item=0x7f0800d7;
        public static int TextAppearance_Widget_AppCompat_Toolbar_Subtitle=0x7f0800d8;
        public static int TextAppearance_Widget_AppCompat_Toolbar_Title=0x7f0800d9;
        public static int Theme=0x7f0800da;
        public static int Theme_AppCompat=0x7f0800db;
        public static int Theme_AppCompat_CompactMenu=0x7f0800dc;
        public static int Theme_AppCompat_Dialog=0x7f0800dd;
        public static int Theme_AppCompat_Dialog_Alert=0x7f0800de;
        public static int Theme_AppCompat_Dialog_MinWidth=0x7f0800df;
        public static int Theme_AppCompat_DialogWhenLarge=0x7f0800e0;
        public static int Theme_AppCompat_Light=0x7f0800e1;
        public static int Theme_AppCompat_Light_DarkActionBar=0x7f0800e2;
        public static int Theme_AppCompat_Light_Dialog=0x7f0800e3;
        public static int Theme_AppCompat_Light_Dialog_Alert=0x7f0800e4;
        public static int Theme_AppCompat_Light_Dialog_MinWidth=0x7f0800e5;
        public static int Theme_AppCompat_Light_DialogWhenLarge=0x7f0800e6;
        public static int Theme_AppCompat_Light_NoActionBar=0x7f0800e7;
        public static int Theme_AppCompat_NoActionBar=0x7f0800e8;
        public static int Theme_Catalyst=0x7f0800e9;
        public static int Theme_Catalyst_RedBox=0x7f0800ea;
        public static int Theme_ReactNative_AppCompat_Light=0x7f0800eb;
        public static int Theme_ReactNative_AppCompat_Light_NoActionBar_FullScreen=0x7f0800ec;
        public static int ThemeOverlay_AppCompat=0x7f0800ed;
        public static int ThemeOverlay_AppCompat_ActionBar=0x7f0800ee;
        public static int ThemeOverlay_AppCompat_Dark=0x7f0800ef;
        public static int ThemeOverlay_AppCompat_Dark_ActionBar=0x7f0800f0;
        public static int ThemeOverlay_AppCompat_Light=0x7f0800f1;
        public static int Widget_AppCompat_ActionBar=0x7f0800f2;
        public static int Widget_AppCompat_ActionBar_Solid=0x7f0800f3;
        public static int Widget_AppCompat_ActionBar_TabBar=0x7f0800f4;
        public static int Widget_AppCompat_ActionBar_TabText=0x7f0800f5;
        public static int Widget_AppCompat_ActionBar_TabView=0x7f0800f6;
        public static int Widget_AppCompat_ActionButton=0x7f0800f7;
        public static int Widget_AppCompat_ActionButton_CloseMode=0x7f0800f8;
        public static int Widget_AppCompat_ActionButton_Overflow=0x7f0800f9;
        public static int Widget_AppCompat_ActionMode=0x7f0800fa;
        public static int Widget_AppCompat_ActivityChooserView=0x7f0800fb;
        public static int Widget_AppCompat_AutoCompleteTextView=0x7f0800fc;
        public static int Widget_AppCompat_Button=0x7f0800fd;
        public static int Widget_AppCompat_Button_Borderless=0x7f0800fe;
        public static int Widget_AppCompat_Button_Borderless_Colored=0x7f0800ff;
        public static int Widget_AppCompat_Button_ButtonBar_AlertDialog=0x7f080100;
        public static int Widget_AppCompat_Button_Colored=0x7f080101;
        public static int Widget_AppCompat_Button_Small=0x7f080102;
        public static int Widget_AppCompat_ButtonBar=0x7f080103;
        public static int Widget_AppCompat_ButtonBar_AlertDialog=0x7f080104;
        public static int Widget_AppCompat_CompoundButton_CheckBox=0x7f080105;
        public static int Widget_AppCompat_CompoundButton_RadioButton=0x7f080106;
        public static int Widget_AppCompat_CompoundButton_Switch=0x7f080107;
        public static int Widget_AppCompat_DrawerArrowToggle=0x7f080108;
        public static int Widget_AppCompat_DropDownItem_Spinner=0x7f080109;
        public static int Widget_AppCompat_EditText=0x7f08010a;
        public static int Widget_AppCompat_Light_ActionBar=0x7f08010b;
        public static int Widget_AppCompat_Light_ActionBar_Solid=0x7f08010c;
        public static int Widget_AppCompat_Light_ActionBar_Solid_Inverse=0x7f08010d;
        public static int Widget_AppCompat_Light_ActionBar_TabBar=0x7f08010e;
        public static int Widget_AppCompat_Light_ActionBar_TabBar_Inverse=0x7f08010f;
        public static int Widget_AppCompat_Light_ActionBar_TabText=0x7f080110;
        public static int Widget_AppCompat_Light_ActionBar_TabText_Inverse=0x7f080111;
        public static int Widget_AppCompat_Light_ActionBar_TabView=0x7f080112;
        public static int Widget_AppCompat_Light_ActionBar_TabView_Inverse=0x7f080113;
        public static int Widget_AppCompat_Light_ActionButton=0x7f080114;
        public static int Widget_AppCompat_Light_ActionButton_CloseMode=0x7f080115;
        public static int Widget_AppCompat_Light_ActionButton_Overflow=0x7f080116;
        public static int Widget_AppCompat_Light_ActionMode_Inverse=0x7f080117;
        public static int Widget_AppCompat_Light_ActivityChooserView=0x7f080118;
        public static int Widget_AppCompat_Light_AutoCompleteTextView=0x7f080119;
        public static int Widget_AppCompat_Light_DropDownItem_Spinner=0x7f08011a;
        public static int Widget_AppCompat_Light_ListPopupWindow=0x7f08011b;
        public static int Widget_AppCompat_Light_ListView_DropDown=0x7f08011c;
        public static int Widget_AppCompat_Light_PopupMenu=0x7f08011d;
        public static int Widget_AppCompat_Light_PopupMenu_Overflow=0x7f08011e;
        public static int Widget_AppCompat_Light_SearchView=0x7f08011f;
        public static int Widget_AppCompat_Light_Spinner_DropDown_ActionBar=0x7f080120;
        public static int Widget_AppCompat_ListPopupWindow=0x7f080121;
        public static int Widget_AppCompat_ListView=0x7f080122;
        public static int Widget_AppCompat_ListView_DropDown=0x7f080123;
        public static int Widget_AppCompat_ListView_Menu=0x7f080124;
        public static int Widget_AppCompat_PopupMenu=0x7f080125;
        public static int Widget_AppCompat_PopupMenu_Overflow=0x7f080126;
        public static int Widget_AppCompat_PopupWindow=0x7f080127;
        public static int Widget_AppCompat_ProgressBar=0x7f080128;
        public static int Widget_AppCompat_ProgressBar_Horizontal=0x7f080129;
        public static int Widget_AppCompat_RatingBar=0x7f08012a;
        public static int Widget_AppCompat_SearchView=0x7f08012b;
        public static int Widget_AppCompat_SearchView_ActionBar=0x7f08012c;
        public static int Widget_AppCompat_Spinner=0x7f08012d;
        public static int Widget_AppCompat_Spinner_DropDown=0x7f08012e;
        public static int Widget_AppCompat_Spinner_DropDown_ActionBar=0x7f08012f;
        public static int Widget_AppCompat_Spinner_Underlined=0x7f080130;
        public static int Widget_AppCompat_TextView_SpinnerItem=0x7f080131;
        public static int Widget_AppCompat_Toolbar=0x7f080132;
        public static int Widget_AppCompat_Toolbar_Button_Navigation=0x7f080133;
    }
    public static final class xml {
        public static int preferences=0x7f050000;
    }
    public static final class styleable {
        /** Attributes that can be used with a ActionBar.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ActionBar_background com.reactlibrary:background}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_backgroundSplit com.reactlibrary:backgroundSplit}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_backgroundStacked com.reactlibrary:backgroundStacked}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_contentInsetEnd com.reactlibrary:contentInsetEnd}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_contentInsetLeft com.reactlibrary:contentInsetLeft}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_contentInsetRight com.reactlibrary:contentInsetRight}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_contentInsetStart com.reactlibrary:contentInsetStart}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_customNavigationLayout com.reactlibrary:customNavigationLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_displayOptions com.reactlibrary:displayOptions}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_divider com.reactlibrary:divider}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_elevation com.reactlibrary:elevation}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_height com.reactlibrary:height}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_hideOnContentScroll com.reactlibrary:hideOnContentScroll}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_homeAsUpIndicator com.reactlibrary:homeAsUpIndicator}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_homeLayout com.reactlibrary:homeLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_icon com.reactlibrary:icon}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_indeterminateProgressStyle com.reactlibrary:indeterminateProgressStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_itemPadding com.reactlibrary:itemPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_logo com.reactlibrary:logo}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_navigationMode com.reactlibrary:navigationMode}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_popupTheme com.reactlibrary:popupTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_progressBarPadding com.reactlibrary:progressBarPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_progressBarStyle com.reactlibrary:progressBarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_subtitle com.reactlibrary:subtitle}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_subtitleTextStyle com.reactlibrary:subtitleTextStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_title com.reactlibrary:title}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionBar_titleTextStyle com.reactlibrary:titleTextStyle}</code></td><td></td></tr>
           </table>
           @see #ActionBar_background
           @see #ActionBar_backgroundSplit
           @see #ActionBar_backgroundStacked
           @see #ActionBar_contentInsetEnd
           @see #ActionBar_contentInsetLeft
           @see #ActionBar_contentInsetRight
           @see #ActionBar_contentInsetStart
           @see #ActionBar_customNavigationLayout
           @see #ActionBar_displayOptions
           @see #ActionBar_divider
           @see #ActionBar_elevation
           @see #ActionBar_height
           @see #ActionBar_hideOnContentScroll
           @see #ActionBar_homeAsUpIndicator
           @see #ActionBar_homeLayout
           @see #ActionBar_icon
           @see #ActionBar_indeterminateProgressStyle
           @see #ActionBar_itemPadding
           @see #ActionBar_logo
           @see #ActionBar_navigationMode
           @see #ActionBar_popupTheme
           @see #ActionBar_progressBarPadding
           @see #ActionBar_progressBarStyle
           @see #ActionBar_subtitle
           @see #ActionBar_subtitleTextStyle
           @see #ActionBar_title
           @see #ActionBar_titleTextStyle
         */
        public static final int[] ActionBar = {
            0x7f010001, 0x7f010003, 0x7f010004, 0x7f010005,
            0x7f010006, 0x7f010007, 0x7f010008, 0x7f010009,
            0x7f01000a, 0x7f01000b, 0x7f01000c, 0x7f01000d,
            0x7f01000e, 0x7f01000f, 0x7f010010, 0x7f010011,
            0x7f010012, 0x7f010013, 0x7f010014, 0x7f010015,
            0x7f010016, 0x7f010017, 0x7f010018, 0x7f010019,
            0x7f01001a, 0x7f01001b, 0x7f010097
        };
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#background}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:background
        */
        public static int ActionBar_background = 10;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#backgroundSplit}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.reactlibrary:backgroundSplit
        */
        public static int ActionBar_backgroundSplit = 12;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#backgroundStacked}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.reactlibrary:backgroundStacked
        */
        public static int ActionBar_backgroundStacked = 11;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#contentInsetEnd}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:contentInsetEnd
        */
        public static int ActionBar_contentInsetEnd = 21;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#contentInsetLeft}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:contentInsetLeft
        */
        public static int ActionBar_contentInsetLeft = 22;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#contentInsetRight}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:contentInsetRight
        */
        public static int ActionBar_contentInsetRight = 23;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#contentInsetStart}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:contentInsetStart
        */
        public static int ActionBar_contentInsetStart = 20;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#customNavigationLayout}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:customNavigationLayout
        */
        public static int ActionBar_customNavigationLayout = 13;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#displayOptions}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>0</td><td></td></tr>
<tr><td><code>useLogo</code></td><td>0x1</td><td></td></tr>
<tr><td><code>showHome</code></td><td>0x2</td><td></td></tr>
<tr><td><code>homeAsUp</code></td><td>0x4</td><td></td></tr>
<tr><td><code>showTitle</code></td><td>0x8</td><td></td></tr>
<tr><td><code>showCustom</code></td><td>0x10</td><td></td></tr>
<tr><td><code>disableHome</code></td><td>0x20</td><td></td></tr>
</table>
          @attr name com.reactlibrary:displayOptions
        */
        public static int ActionBar_displayOptions = 3;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#divider}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:divider
        */
        public static int ActionBar_divider = 9;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#elevation}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:elevation
        */
        public static int ActionBar_elevation = 24;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#height}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:height
        */
        public static int ActionBar_height = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#hideOnContentScroll}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:hideOnContentScroll
        */
        public static int ActionBar_hideOnContentScroll = 19;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#homeAsUpIndicator}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:homeAsUpIndicator
        */
        public static int ActionBar_homeAsUpIndicator = 26;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#homeLayout}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:homeLayout
        */
        public static int ActionBar_homeLayout = 14;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#icon}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:icon
        */
        public static int ActionBar_icon = 7;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#indeterminateProgressStyle}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:indeterminateProgressStyle
        */
        public static int ActionBar_indeterminateProgressStyle = 16;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#itemPadding}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:itemPadding
        */
        public static int ActionBar_itemPadding = 18;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#logo}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:logo
        */
        public static int ActionBar_logo = 8;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#navigationMode}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>normal</code></td><td>0</td><td></td></tr>
<tr><td><code>listMode</code></td><td>1</td><td></td></tr>
<tr><td><code>tabMode</code></td><td>2</td><td></td></tr>
</table>
          @attr name com.reactlibrary:navigationMode
        */
        public static int ActionBar_navigationMode = 2;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#popupTheme}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:popupTheme
        */
        public static int ActionBar_popupTheme = 25;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#progressBarPadding}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:progressBarPadding
        */
        public static int ActionBar_progressBarPadding = 17;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#progressBarStyle}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:progressBarStyle
        */
        public static int ActionBar_progressBarStyle = 15;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#subtitle}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:subtitle
        */
        public static int ActionBar_subtitle = 4;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#subtitleTextStyle}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:subtitleTextStyle
        */
        public static int ActionBar_subtitleTextStyle = 6;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#title}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:title
        */
        public static int ActionBar_title = 1;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#titleTextStyle}
          attribute's value can be found in the {@link #ActionBar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:titleTextStyle
        */
        public static int ActionBar_titleTextStyle = 5;
        /** Attributes that can be used with a ActionBarLayout.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ActionBarLayout_android_layout_gravity android:layout_gravity}</code></td><td></td></tr>
           </table>
           @see #ActionBarLayout_android_layout_gravity
         */
        public static final int[] ActionBarLayout = {
            0x010100b3
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout_gravity}
          attribute's value can be found in the {@link #ActionBarLayout} array.
          @attr name android:layout_gravity
        */
        public static int ActionBarLayout_android_layout_gravity = 0;
        /** Attributes that can be used with a ActionMenuItemView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ActionMenuItemView_android_minWidth android:minWidth}</code></td><td></td></tr>
           </table>
           @see #ActionMenuItemView_android_minWidth
         */
        public static final int[] ActionMenuItemView = {
            0x0101013f
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#minWidth}
          attribute's value can be found in the {@link #ActionMenuItemView} array.
          @attr name android:minWidth
        */
        public static int ActionMenuItemView_android_minWidth = 0;
        /** Attributes that can be used with a ActionMenuView.
         */
        public static final int[] ActionMenuView = {
            
        };
        /** Attributes that can be used with a ActionMode.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ActionMode_background com.reactlibrary:background}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionMode_backgroundSplit com.reactlibrary:backgroundSplit}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionMode_closeItemLayout com.reactlibrary:closeItemLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionMode_height com.reactlibrary:height}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionMode_subtitleTextStyle com.reactlibrary:subtitleTextStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #ActionMode_titleTextStyle com.reactlibrary:titleTextStyle}</code></td><td></td></tr>
           </table>
           @see #ActionMode_background
           @see #ActionMode_backgroundSplit
           @see #ActionMode_closeItemLayout
           @see #ActionMode_height
           @see #ActionMode_subtitleTextStyle
           @see #ActionMode_titleTextStyle
         */
        public static final int[] ActionMode = {
            0x7f010001, 0x7f010007, 0x7f010008, 0x7f01000c,
            0x7f01000e, 0x7f01001c
        };
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#background}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:background
        */
        public static int ActionMode_background = 3;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#backgroundSplit}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.reactlibrary:backgroundSplit
        */
        public static int ActionMode_backgroundSplit = 4;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#closeItemLayout}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:closeItemLayout
        */
        public static int ActionMode_closeItemLayout = 5;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#height}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:height
        */
        public static int ActionMode_height = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#subtitleTextStyle}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:subtitleTextStyle
        */
        public static int ActionMode_subtitleTextStyle = 2;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#titleTextStyle}
          attribute's value can be found in the {@link #ActionMode} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:titleTextStyle
        */
        public static int ActionMode_titleTextStyle = 1;
        /** Attributes that can be used with a ActivityChooserView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ActivityChooserView_expandActivityOverflowButtonDrawable com.reactlibrary:expandActivityOverflowButtonDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #ActivityChooserView_initialActivityCount com.reactlibrary:initialActivityCount}</code></td><td></td></tr>
           </table>
           @see #ActivityChooserView_expandActivityOverflowButtonDrawable
           @see #ActivityChooserView_initialActivityCount
         */
        public static final int[] ActivityChooserView = {
            0x7f01001d, 0x7f01001e
        };
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#expandActivityOverflowButtonDrawable}
          attribute's value can be found in the {@link #ActivityChooserView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:expandActivityOverflowButtonDrawable
        */
        public static int ActivityChooserView_expandActivityOverflowButtonDrawable = 1;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#initialActivityCount}
          attribute's value can be found in the {@link #ActivityChooserView} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:initialActivityCount
        */
        public static int ActivityChooserView_initialActivityCount = 0;
        /** Attributes that can be used with a AlertDialog.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #AlertDialog_android_layout android:layout}</code></td><td></td></tr>
           <tr><td><code>{@link #AlertDialog_buttonPanelSideLayout com.reactlibrary:buttonPanelSideLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #AlertDialog_listItemLayout com.reactlibrary:listItemLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #AlertDialog_listLayout com.reactlibrary:listLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #AlertDialog_multiChoiceItemLayout com.reactlibrary:multiChoiceItemLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #AlertDialog_singleChoiceItemLayout com.reactlibrary:singleChoiceItemLayout}</code></td><td></td></tr>
           </table>
           @see #AlertDialog_android_layout
           @see #AlertDialog_buttonPanelSideLayout
           @see #AlertDialog_listItemLayout
           @see #AlertDialog_listLayout
           @see #AlertDialog_multiChoiceItemLayout
           @see #AlertDialog_singleChoiceItemLayout
         */
        public static final int[] AlertDialog = {
            0x010100f2, 0x7f01001f, 0x7f010020, 0x7f010021,
            0x7f010022, 0x7f010023
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout}
          attribute's value can be found in the {@link #AlertDialog} array.
          @attr name android:layout
        */
        public static int AlertDialog_android_layout = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#buttonPanelSideLayout}
          attribute's value can be found in the {@link #AlertDialog} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:buttonPanelSideLayout
        */
        public static int AlertDialog_buttonPanelSideLayout = 1;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#listItemLayout}
          attribute's value can be found in the {@link #AlertDialog} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:listItemLayout
        */
        public static int AlertDialog_listItemLayout = 5;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#listLayout}
          attribute's value can be found in the {@link #AlertDialog} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:listLayout
        */
        public static int AlertDialog_listLayout = 2;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#multiChoiceItemLayout}
          attribute's value can be found in the {@link #AlertDialog} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:multiChoiceItemLayout
        */
        public static int AlertDialog_multiChoiceItemLayout = 3;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#singleChoiceItemLayout}
          attribute's value can be found in the {@link #AlertDialog} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:singleChoiceItemLayout
        */
        public static int AlertDialog_singleChoiceItemLayout = 4;
        /** Attributes that can be used with a AppCompatTextView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #AppCompatTextView_android_textAppearance android:textAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #AppCompatTextView_textAllCaps com.reactlibrary:textAllCaps}</code></td><td></td></tr>
           </table>
           @see #AppCompatTextView_android_textAppearance
           @see #AppCompatTextView_textAllCaps
         */
        public static final int[] AppCompatTextView = {
            0x01010034, 0x7f010024
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textAppearance}
          attribute's value can be found in the {@link #AppCompatTextView} array.
          @attr name android:textAppearance
        */
        public static int AppCompatTextView_android_textAppearance = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#textAllCaps}
          attribute's value can be found in the {@link #AppCompatTextView} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a boolean value, either "<code>true</code>" or "<code>false</code>".
          @attr name com.reactlibrary:textAllCaps
        */
        public static int AppCompatTextView_textAllCaps = 1;
        /** Attributes that can be used with a CompoundButton.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #CompoundButton_android_button android:button}</code></td><td></td></tr>
           <tr><td><code>{@link #CompoundButton_buttonTint com.reactlibrary:buttonTint}</code></td><td></td></tr>
           <tr><td><code>{@link #CompoundButton_buttonTintMode com.reactlibrary:buttonTintMode}</code></td><td></td></tr>
           </table>
           @see #CompoundButton_android_button
           @see #CompoundButton_buttonTint
           @see #CompoundButton_buttonTintMode
         */
        public static final int[] CompoundButton = {
            0x01010107, 0x7f010025, 0x7f010026
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#button}
          attribute's value can be found in the {@link #CompoundButton} array.
          @attr name android:button
        */
        public static int CompoundButton_android_button = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#buttonTint}
          attribute's value can be found in the {@link #CompoundButton} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:buttonTint
        */
        public static int CompoundButton_buttonTint = 1;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#buttonTintMode}
          attribute's value can be found in the {@link #CompoundButton} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>src_over</code></td><td>3</td><td></td></tr>
<tr><td><code>src_in</code></td><td>5</td><td></td></tr>
<tr><td><code>src_atop</code></td><td>9</td><td></td></tr>
<tr><td><code>multiply</code></td><td>14</td><td></td></tr>
<tr><td><code>screen</code></td><td>15</td><td></td></tr>
</table>
          @attr name com.reactlibrary:buttonTintMode
        */
        public static int CompoundButton_buttonTintMode = 2;
        /** Attributes that can be used with a DrawerArrowToggle.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #DrawerArrowToggle_arrowHeadLength com.reactlibrary:arrowHeadLength}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_arrowShaftLength com.reactlibrary:arrowShaftLength}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_barLength com.reactlibrary:barLength}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_color com.reactlibrary:color}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_drawableSize com.reactlibrary:drawableSize}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_gapBetweenBars com.reactlibrary:gapBetweenBars}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_spinBars com.reactlibrary:spinBars}</code></td><td></td></tr>
           <tr><td><code>{@link #DrawerArrowToggle_thickness com.reactlibrary:thickness}</code></td><td></td></tr>
           </table>
           @see #DrawerArrowToggle_arrowHeadLength
           @see #DrawerArrowToggle_arrowShaftLength
           @see #DrawerArrowToggle_barLength
           @see #DrawerArrowToggle_color
           @see #DrawerArrowToggle_drawableSize
           @see #DrawerArrowToggle_gapBetweenBars
           @see #DrawerArrowToggle_spinBars
           @see #DrawerArrowToggle_thickness
         */
        public static final int[] DrawerArrowToggle = {
            0x7f010027, 0x7f010028, 0x7f010029, 0x7f01002a,
            0x7f01002b, 0x7f01002c, 0x7f01002d, 0x7f01002e
        };
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#arrowHeadLength}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:arrowHeadLength
        */
        public static int DrawerArrowToggle_arrowHeadLength = 4;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#arrowShaftLength}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:arrowShaftLength
        */
        public static int DrawerArrowToggle_arrowShaftLength = 5;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#barLength}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:barLength
        */
        public static int DrawerArrowToggle_barLength = 6;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#color}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:color
        */
        public static int DrawerArrowToggle_color = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#drawableSize}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:drawableSize
        */
        public static int DrawerArrowToggle_drawableSize = 2;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#gapBetweenBars}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:gapBetweenBars
        */
        public static int DrawerArrowToggle_gapBetweenBars = 3;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#spinBars}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:spinBars
        */
        public static int DrawerArrowToggle_spinBars = 1;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#thickness}
          attribute's value can be found in the {@link #DrawerArrowToggle} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:thickness
        */
        public static int DrawerArrowToggle_thickness = 7;
        /** Attributes that can be used with a GenericDraweeView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #GenericDraweeView_actualImageScaleType com.reactlibrary:actualImageScaleType}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_backgroundImage com.reactlibrary:backgroundImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_fadeDuration com.reactlibrary:fadeDuration}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_failureImage com.reactlibrary:failureImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_failureImageScaleType com.reactlibrary:failureImageScaleType}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_overlayImage com.reactlibrary:overlayImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_placeholderImage com.reactlibrary:placeholderImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_placeholderImageScaleType com.reactlibrary:placeholderImageScaleType}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_pressedStateOverlayImage com.reactlibrary:pressedStateOverlayImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_progressBarAutoRotateInterval com.reactlibrary:progressBarAutoRotateInterval}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_progressBarImage com.reactlibrary:progressBarImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_progressBarImageScaleType com.reactlibrary:progressBarImageScaleType}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_retryImage com.reactlibrary:retryImage}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_retryImageScaleType com.reactlibrary:retryImageScaleType}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_roundAsCircle com.reactlibrary:roundAsCircle}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_roundBottomLeft com.reactlibrary:roundBottomLeft}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_roundBottomRight com.reactlibrary:roundBottomRight}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_roundTopLeft com.reactlibrary:roundTopLeft}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_roundTopRight com.reactlibrary:roundTopRight}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_roundWithOverlayColor com.reactlibrary:roundWithOverlayColor}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_roundedCornerRadius com.reactlibrary:roundedCornerRadius}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_roundingBorderColor com.reactlibrary:roundingBorderColor}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_roundingBorderWidth com.reactlibrary:roundingBorderWidth}</code></td><td></td></tr>
           <tr><td><code>{@link #GenericDraweeView_viewAspectRatio com.reactlibrary:viewAspectRatio}</code></td><td></td></tr>
           </table>
           @see #GenericDraweeView_actualImageScaleType
           @see #GenericDraweeView_backgroundImage
           @see #GenericDraweeView_fadeDuration
           @see #GenericDraweeView_failureImage
           @see #GenericDraweeView_failureImageScaleType
           @see #GenericDraweeView_overlayImage
           @see #GenericDraweeView_placeholderImage
           @see #GenericDraweeView_placeholderImageScaleType
           @see #GenericDraweeView_pressedStateOverlayImage
           @see #GenericDraweeView_progressBarAutoRotateInterval
           @see #GenericDraweeView_progressBarImage
           @see #GenericDraweeView_progressBarImageScaleType
           @see #GenericDraweeView_retryImage
           @see #GenericDraweeView_retryImageScaleType
           @see #GenericDraweeView_roundAsCircle
           @see #GenericDraweeView_roundBottomLeft
           @see #GenericDraweeView_roundBottomRight
           @see #GenericDraweeView_roundTopLeft
           @see #GenericDraweeView_roundTopRight
           @see #GenericDraweeView_roundWithOverlayColor
           @see #GenericDraweeView_roundedCornerRadius
           @see #GenericDraweeView_roundingBorderColor
           @see #GenericDraweeView_roundingBorderWidth
           @see #GenericDraweeView_viewAspectRatio
         */
        public static final int[] GenericDraweeView = {
            0x7f01002f, 0x7f010030, 0x7f010031, 0x7f010032,
            0x7f010033, 0x7f010034, 0x7f010035, 0x7f010036,
            0x7f010037, 0x7f010038, 0x7f010039, 0x7f01003a,
            0x7f01003b, 0x7f01003c, 0x7f01003d, 0x7f01003e,
            0x7f01003f, 0x7f010040, 0x7f010041, 0x7f010042,
            0x7f010043, 0x7f010044, 0x7f010045, 0x7f010046
        };
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actualImageScaleType}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
          @attr name com.reactlibrary:actualImageScaleType
        */
        public static int GenericDraweeView_actualImageScaleType = 11;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#backgroundImage}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:backgroundImage
        */
        public static int GenericDraweeView_backgroundImage = 12;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#fadeDuration}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be an integer value, such as "<code>100</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:fadeDuration
        */
        public static int GenericDraweeView_fadeDuration = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#failureImage}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:failureImage
        */
        public static int GenericDraweeView_failureImage = 6;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#failureImageScaleType}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
          @attr name com.reactlibrary:failureImageScaleType
        */
        public static int GenericDraweeView_failureImageScaleType = 7;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#overlayImage}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:overlayImage
        */
        public static int GenericDraweeView_overlayImage = 13;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#placeholderImage}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:placeholderImage
        */
        public static int GenericDraweeView_placeholderImage = 2;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#placeholderImageScaleType}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
          @attr name com.reactlibrary:placeholderImageScaleType
        */
        public static int GenericDraweeView_placeholderImageScaleType = 3;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#pressedStateOverlayImage}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:pressedStateOverlayImage
        */
        public static int GenericDraweeView_pressedStateOverlayImage = 14;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#progressBarAutoRotateInterval}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be an integer value, such as "<code>100</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:progressBarAutoRotateInterval
        */
        public static int GenericDraweeView_progressBarAutoRotateInterval = 10;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#progressBarImage}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:progressBarImage
        */
        public static int GenericDraweeView_progressBarImage = 8;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#progressBarImageScaleType}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
          @attr name com.reactlibrary:progressBarImageScaleType
        */
        public static int GenericDraweeView_progressBarImageScaleType = 9;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#retryImage}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:retryImage
        */
        public static int GenericDraweeView_retryImage = 4;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#retryImageScaleType}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>-1</td><td></td></tr>
<tr><td><code>fitXY</code></td><td>0</td><td></td></tr>
<tr><td><code>fitStart</code></td><td>1</td><td></td></tr>
<tr><td><code>fitCenter</code></td><td>2</td><td></td></tr>
<tr><td><code>fitEnd</code></td><td>3</td><td></td></tr>
<tr><td><code>center</code></td><td>4</td><td></td></tr>
<tr><td><code>centerInside</code></td><td>5</td><td></td></tr>
<tr><td><code>centerCrop</code></td><td>6</td><td></td></tr>
<tr><td><code>focusCrop</code></td><td>7</td><td></td></tr>
</table>
          @attr name com.reactlibrary:retryImageScaleType
        */
        public static int GenericDraweeView_retryImageScaleType = 5;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#roundAsCircle}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:roundAsCircle
        */
        public static int GenericDraweeView_roundAsCircle = 15;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#roundBottomLeft}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:roundBottomLeft
        */
        public static int GenericDraweeView_roundBottomLeft = 20;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#roundBottomRight}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:roundBottomRight
        */
        public static int GenericDraweeView_roundBottomRight = 19;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#roundTopLeft}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:roundTopLeft
        */
        public static int GenericDraweeView_roundTopLeft = 17;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#roundTopRight}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:roundTopRight
        */
        public static int GenericDraweeView_roundTopRight = 18;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#roundWithOverlayColor}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:roundWithOverlayColor
        */
        public static int GenericDraweeView_roundWithOverlayColor = 21;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#roundedCornerRadius}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:roundedCornerRadius
        */
        public static int GenericDraweeView_roundedCornerRadius = 16;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#roundingBorderColor}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:roundingBorderColor
        */
        public static int GenericDraweeView_roundingBorderColor = 23;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#roundingBorderWidth}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:roundingBorderWidth
        */
        public static int GenericDraweeView_roundingBorderWidth = 22;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#viewAspectRatio}
          attribute's value can be found in the {@link #GenericDraweeView} array.


          <p>Must be a floating point value, such as "<code>1.2</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:viewAspectRatio
        */
        public static int GenericDraweeView_viewAspectRatio = 1;
        /** Attributes that can be used with a LinearLayoutCompat.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #LinearLayoutCompat_android_baselineAligned android:baselineAligned}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_android_baselineAlignedChildIndex android:baselineAlignedChildIndex}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_android_gravity android:gravity}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_android_orientation android:orientation}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_android_weightSum android:weightSum}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_divider com.reactlibrary:divider}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_dividerPadding com.reactlibrary:dividerPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_measureWithLargestChild com.reactlibrary:measureWithLargestChild}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_showDividers com.reactlibrary:showDividers}</code></td><td></td></tr>
           </table>
           @see #LinearLayoutCompat_android_baselineAligned
           @see #LinearLayoutCompat_android_baselineAlignedChildIndex
           @see #LinearLayoutCompat_android_gravity
           @see #LinearLayoutCompat_android_orientation
           @see #LinearLayoutCompat_android_weightSum
           @see #LinearLayoutCompat_divider
           @see #LinearLayoutCompat_dividerPadding
           @see #LinearLayoutCompat_measureWithLargestChild
           @see #LinearLayoutCompat_showDividers
         */
        public static final int[] LinearLayoutCompat = {
            0x010100af, 0x010100c4, 0x01010126, 0x01010127,
            0x01010128, 0x7f01000b, 0x7f010047, 0x7f010048,
            0x7f010049
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#baselineAligned}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.
          @attr name android:baselineAligned
        */
        public static int LinearLayoutCompat_android_baselineAligned = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#baselineAlignedChildIndex}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.
          @attr name android:baselineAlignedChildIndex
        */
        public static int LinearLayoutCompat_android_baselineAlignedChildIndex = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#gravity}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.
          @attr name android:gravity
        */
        public static int LinearLayoutCompat_android_gravity = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#orientation}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.
          @attr name android:orientation
        */
        public static int LinearLayoutCompat_android_orientation = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#weightSum}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.
          @attr name android:weightSum
        */
        public static int LinearLayoutCompat_android_weightSum = 4;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#divider}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:divider
        */
        public static int LinearLayoutCompat_divider = 5;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#dividerPadding}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:dividerPadding
        */
        public static int LinearLayoutCompat_dividerPadding = 8;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#measureWithLargestChild}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:measureWithLargestChild
        */
        public static int LinearLayoutCompat_measureWithLargestChild = 6;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#showDividers}
          attribute's value can be found in the {@link #LinearLayoutCompat} array.


          <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>none</code></td><td>0</td><td></td></tr>
<tr><td><code>beginning</code></td><td>1</td><td></td></tr>
<tr><td><code>middle</code></td><td>2</td><td></td></tr>
<tr><td><code>end</code></td><td>4</td><td></td></tr>
</table>
          @attr name com.reactlibrary:showDividers
        */
        public static int LinearLayoutCompat_showDividers = 7;
        /** Attributes that can be used with a LinearLayoutCompat_Layout.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #LinearLayoutCompat_Layout_android_layout_gravity android:layout_gravity}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_Layout_android_layout_height android:layout_height}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_Layout_android_layout_weight android:layout_weight}</code></td><td></td></tr>
           <tr><td><code>{@link #LinearLayoutCompat_Layout_android_layout_width android:layout_width}</code></td><td></td></tr>
           </table>
           @see #LinearLayoutCompat_Layout_android_layout_gravity
           @see #LinearLayoutCompat_Layout_android_layout_height
           @see #LinearLayoutCompat_Layout_android_layout_weight
           @see #LinearLayoutCompat_Layout_android_layout_width
         */
        public static final int[] LinearLayoutCompat_Layout = {
            0x010100b3, 0x010100f4, 0x010100f5, 0x01010181
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout_gravity}
          attribute's value can be found in the {@link #LinearLayoutCompat_Layout} array.
          @attr name android:layout_gravity
        */
        public static int LinearLayoutCompat_Layout_android_layout_gravity = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout_height}
          attribute's value can be found in the {@link #LinearLayoutCompat_Layout} array.
          @attr name android:layout_height
        */
        public static int LinearLayoutCompat_Layout_android_layout_height = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout_weight}
          attribute's value can be found in the {@link #LinearLayoutCompat_Layout} array.
          @attr name android:layout_weight
        */
        public static int LinearLayoutCompat_Layout_android_layout_weight = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout_width}
          attribute's value can be found in the {@link #LinearLayoutCompat_Layout} array.
          @attr name android:layout_width
        */
        public static int LinearLayoutCompat_Layout_android_layout_width = 1;
        /** Attributes that can be used with a ListPopupWindow.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ListPopupWindow_android_dropDownHorizontalOffset android:dropDownHorizontalOffset}</code></td><td></td></tr>
           <tr><td><code>{@link #ListPopupWindow_android_dropDownVerticalOffset android:dropDownVerticalOffset}</code></td><td></td></tr>
           </table>
           @see #ListPopupWindow_android_dropDownHorizontalOffset
           @see #ListPopupWindow_android_dropDownVerticalOffset
         */
        public static final int[] ListPopupWindow = {
            0x010102ac, 0x010102ad
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#dropDownHorizontalOffset}
          attribute's value can be found in the {@link #ListPopupWindow} array.
          @attr name android:dropDownHorizontalOffset
        */
        public static int ListPopupWindow_android_dropDownHorizontalOffset = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#dropDownVerticalOffset}
          attribute's value can be found in the {@link #ListPopupWindow} array.
          @attr name android:dropDownVerticalOffset
        */
        public static int ListPopupWindow_android_dropDownVerticalOffset = 1;
        /** Attributes that can be used with a MenuGroup.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #MenuGroup_android_checkableBehavior android:checkableBehavior}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuGroup_android_enabled android:enabled}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuGroup_android_id android:id}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuGroup_android_menuCategory android:menuCategory}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuGroup_android_orderInCategory android:orderInCategory}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuGroup_android_visible android:visible}</code></td><td></td></tr>
           </table>
           @see #MenuGroup_android_checkableBehavior
           @see #MenuGroup_android_enabled
           @see #MenuGroup_android_id
           @see #MenuGroup_android_menuCategory
           @see #MenuGroup_android_orderInCategory
           @see #MenuGroup_android_visible
         */
        public static final int[] MenuGroup = {
            0x0101000e, 0x010100d0, 0x01010194, 0x010101de,
            0x010101df, 0x010101e0
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#checkableBehavior}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:checkableBehavior
        */
        public static int MenuGroup_android_checkableBehavior = 5;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#enabled}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:enabled
        */
        public static int MenuGroup_android_enabled = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#id}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:id
        */
        public static int MenuGroup_android_id = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#menuCategory}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:menuCategory
        */
        public static int MenuGroup_android_menuCategory = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#orderInCategory}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:orderInCategory
        */
        public static int MenuGroup_android_orderInCategory = 4;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#visible}
          attribute's value can be found in the {@link #MenuGroup} array.
          @attr name android:visible
        */
        public static int MenuGroup_android_visible = 2;
        /** Attributes that can be used with a MenuItem.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #MenuItem_actionLayout com.reactlibrary:actionLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_actionProviderClass com.reactlibrary:actionProviderClass}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_actionViewClass com.reactlibrary:actionViewClass}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_alphabeticShortcut android:alphabeticShortcut}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_checkable android:checkable}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_checked android:checked}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_enabled android:enabled}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_icon android:icon}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_id android:id}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_menuCategory android:menuCategory}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_numericShortcut android:numericShortcut}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_onClick android:onClick}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_orderInCategory android:orderInCategory}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_title android:title}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_titleCondensed android:titleCondensed}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_android_visible android:visible}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuItem_showAsAction com.reactlibrary:showAsAction}</code></td><td></td></tr>
           </table>
           @see #MenuItem_actionLayout
           @see #MenuItem_actionProviderClass
           @see #MenuItem_actionViewClass
           @see #MenuItem_android_alphabeticShortcut
           @see #MenuItem_android_checkable
           @see #MenuItem_android_checked
           @see #MenuItem_android_enabled
           @see #MenuItem_android_icon
           @see #MenuItem_android_id
           @see #MenuItem_android_menuCategory
           @see #MenuItem_android_numericShortcut
           @see #MenuItem_android_onClick
           @see #MenuItem_android_orderInCategory
           @see #MenuItem_android_title
           @see #MenuItem_android_titleCondensed
           @see #MenuItem_android_visible
           @see #MenuItem_showAsAction
         */
        public static final int[] MenuItem = {
            0x01010002, 0x0101000e, 0x010100d0, 0x01010106,
            0x01010194, 0x010101de, 0x010101df, 0x010101e1,
            0x010101e2, 0x010101e3, 0x010101e4, 0x010101e5,
            0x0101026f, 0x7f01004a, 0x7f01004b, 0x7f01004c,
            0x7f01004d
        };
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionLayout}
          attribute's value can be found in the {@link #MenuItem} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionLayout
        */
        public static int MenuItem_actionLayout = 14;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionProviderClass}
          attribute's value can be found in the {@link #MenuItem} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:actionProviderClass
        */
        public static int MenuItem_actionProviderClass = 16;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionViewClass}
          attribute's value can be found in the {@link #MenuItem} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:actionViewClass
        */
        public static int MenuItem_actionViewClass = 15;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#alphabeticShortcut}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:alphabeticShortcut
        */
        public static int MenuItem_android_alphabeticShortcut = 9;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#checkable}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:checkable
        */
        public static int MenuItem_android_checkable = 11;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#checked}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:checked
        */
        public static int MenuItem_android_checked = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#enabled}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:enabled
        */
        public static int MenuItem_android_enabled = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#icon}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:icon
        */
        public static int MenuItem_android_icon = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#id}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:id
        */
        public static int MenuItem_android_id = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#menuCategory}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:menuCategory
        */
        public static int MenuItem_android_menuCategory = 5;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#numericShortcut}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:numericShortcut
        */
        public static int MenuItem_android_numericShortcut = 10;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#onClick}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:onClick
        */
        public static int MenuItem_android_onClick = 12;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#orderInCategory}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:orderInCategory
        */
        public static int MenuItem_android_orderInCategory = 6;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#title}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:title
        */
        public static int MenuItem_android_title = 7;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#titleCondensed}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:titleCondensed
        */
        public static int MenuItem_android_titleCondensed = 8;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#visible}
          attribute's value can be found in the {@link #MenuItem} array.
          @attr name android:visible
        */
        public static int MenuItem_android_visible = 4;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#showAsAction}
          attribute's value can be found in the {@link #MenuItem} array.


          <p>Must be one or more (separated by '|') of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>never</code></td><td>0</td><td></td></tr>
<tr><td><code>ifRoom</code></td><td>1</td><td></td></tr>
<tr><td><code>always</code></td><td>2</td><td></td></tr>
<tr><td><code>withText</code></td><td>4</td><td></td></tr>
<tr><td><code>collapseActionView</code></td><td>8</td><td></td></tr>
</table>
          @attr name com.reactlibrary:showAsAction
        */
        public static int MenuItem_showAsAction = 13;
        /** Attributes that can be used with a MenuView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #MenuView_android_headerBackground android:headerBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_horizontalDivider android:horizontalDivider}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_itemBackground android:itemBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_itemIconDisabledAlpha android:itemIconDisabledAlpha}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_itemTextAppearance android:itemTextAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_verticalDivider android:verticalDivider}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_android_windowAnimationStyle android:windowAnimationStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #MenuView_preserveIconSpacing com.reactlibrary:preserveIconSpacing}</code></td><td></td></tr>
           </table>
           @see #MenuView_android_headerBackground
           @see #MenuView_android_horizontalDivider
           @see #MenuView_android_itemBackground
           @see #MenuView_android_itemIconDisabledAlpha
           @see #MenuView_android_itemTextAppearance
           @see #MenuView_android_verticalDivider
           @see #MenuView_android_windowAnimationStyle
           @see #MenuView_preserveIconSpacing
         */
        public static final int[] MenuView = {
            0x010100ae, 0x0101012c, 0x0101012d, 0x0101012e,
            0x0101012f, 0x01010130, 0x01010131, 0x7f01004e
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#headerBackground}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:headerBackground
        */
        public static int MenuView_android_headerBackground = 4;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#horizontalDivider}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:horizontalDivider
        */
        public static int MenuView_android_horizontalDivider = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#itemBackground}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:itemBackground
        */
        public static int MenuView_android_itemBackground = 5;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#itemIconDisabledAlpha}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:itemIconDisabledAlpha
        */
        public static int MenuView_android_itemIconDisabledAlpha = 6;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#itemTextAppearance}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:itemTextAppearance
        */
        public static int MenuView_android_itemTextAppearance = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#verticalDivider}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:verticalDivider
        */
        public static int MenuView_android_verticalDivider = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#windowAnimationStyle}
          attribute's value can be found in the {@link #MenuView} array.
          @attr name android:windowAnimationStyle
        */
        public static int MenuView_android_windowAnimationStyle = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#preserveIconSpacing}
          attribute's value can be found in the {@link #MenuView} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:preserveIconSpacing
        */
        public static int MenuView_preserveIconSpacing = 7;
        /** Attributes that can be used with a PopupWindow.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #PopupWindow_android_popupBackground android:popupBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #PopupWindow_overlapAnchor com.reactlibrary:overlapAnchor}</code></td><td></td></tr>
           </table>
           @see #PopupWindow_android_popupBackground
           @see #PopupWindow_overlapAnchor
         */
        public static final int[] PopupWindow = {
            0x01010176, 0x7f01004f
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#popupBackground}
          attribute's value can be found in the {@link #PopupWindow} array.
          @attr name android:popupBackground
        */
        public static int PopupWindow_android_popupBackground = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#overlapAnchor}
          attribute's value can be found in the {@link #PopupWindow} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:overlapAnchor
        */
        public static int PopupWindow_overlapAnchor = 1;
        /** Attributes that can be used with a PopupWindowBackgroundState.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #PopupWindowBackgroundState_state_above_anchor com.reactlibrary:state_above_anchor}</code></td><td></td></tr>
           </table>
           @see #PopupWindowBackgroundState_state_above_anchor
         */
        public static final int[] PopupWindowBackgroundState = {
            0x7f010050
        };
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#state_above_anchor}
          attribute's value can be found in the {@link #PopupWindowBackgroundState} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:state_above_anchor
        */
        public static int PopupWindowBackgroundState_state_above_anchor = 0;
        /** Attributes that can be used with a RecyclerView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #RecyclerView_android_orientation android:orientation}</code></td><td></td></tr>
           <tr><td><code>{@link #RecyclerView_layoutManager com.reactlibrary:layoutManager}</code></td><td></td></tr>
           <tr><td><code>{@link #RecyclerView_reverseLayout com.reactlibrary:reverseLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #RecyclerView_spanCount com.reactlibrary:spanCount}</code></td><td></td></tr>
           <tr><td><code>{@link #RecyclerView_stackFromEnd com.reactlibrary:stackFromEnd}</code></td><td></td></tr>
           </table>
           @see #RecyclerView_android_orientation
           @see #RecyclerView_layoutManager
           @see #RecyclerView_reverseLayout
           @see #RecyclerView_spanCount
           @see #RecyclerView_stackFromEnd
         */
        public static final int[] RecyclerView = {
            0x010100c4, 0x7f010051, 0x7f010052, 0x7f010053,
            0x7f010054
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#orientation}
          attribute's value can be found in the {@link #RecyclerView} array.
          @attr name android:orientation
        */
        public static int RecyclerView_android_orientation = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#layoutManager}
          attribute's value can be found in the {@link #RecyclerView} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:layoutManager
        */
        public static int RecyclerView_layoutManager = 1;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#reverseLayout}
          attribute's value can be found in the {@link #RecyclerView} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:reverseLayout
        */
        public static int RecyclerView_reverseLayout = 3;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#spanCount}
          attribute's value can be found in the {@link #RecyclerView} array.


          <p>Must be an integer value, such as "<code>100</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:spanCount
        */
        public static int RecyclerView_spanCount = 2;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#stackFromEnd}
          attribute's value can be found in the {@link #RecyclerView} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:stackFromEnd
        */
        public static int RecyclerView_stackFromEnd = 4;
        /** Attributes that can be used with a SearchView.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #SearchView_android_focusable android:focusable}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_android_imeOptions android:imeOptions}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_android_inputType android:inputType}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_android_maxWidth android:maxWidth}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_closeIcon com.reactlibrary:closeIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_commitIcon com.reactlibrary:commitIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_defaultQueryHint com.reactlibrary:defaultQueryHint}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_goIcon com.reactlibrary:goIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_iconifiedByDefault com.reactlibrary:iconifiedByDefault}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_layout com.reactlibrary:layout}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_queryBackground com.reactlibrary:queryBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_queryHint com.reactlibrary:queryHint}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_searchHintIcon com.reactlibrary:searchHintIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_searchIcon com.reactlibrary:searchIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_submitBackground com.reactlibrary:submitBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_suggestionRowLayout com.reactlibrary:suggestionRowLayout}</code></td><td></td></tr>
           <tr><td><code>{@link #SearchView_voiceIcon com.reactlibrary:voiceIcon}</code></td><td></td></tr>
           </table>
           @see #SearchView_android_focusable
           @see #SearchView_android_imeOptions
           @see #SearchView_android_inputType
           @see #SearchView_android_maxWidth
           @see #SearchView_closeIcon
           @see #SearchView_commitIcon
           @see #SearchView_defaultQueryHint
           @see #SearchView_goIcon
           @see #SearchView_iconifiedByDefault
           @see #SearchView_layout
           @see #SearchView_queryBackground
           @see #SearchView_queryHint
           @see #SearchView_searchHintIcon
           @see #SearchView_searchIcon
           @see #SearchView_submitBackground
           @see #SearchView_suggestionRowLayout
           @see #SearchView_voiceIcon
         */
        public static final int[] SearchView = {
            0x010100da, 0x0101011f, 0x01010220, 0x01010264,
            0x7f010055, 0x7f010056, 0x7f010057, 0x7f010058,
            0x7f010059, 0x7f01005a, 0x7f01005b, 0x7f01005c,
            0x7f01005d, 0x7f01005e, 0x7f01005f, 0x7f010060,
            0x7f010061
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#focusable}
          attribute's value can be found in the {@link #SearchView} array.
          @attr name android:focusable
        */
        public static int SearchView_android_focusable = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#imeOptions}
          attribute's value can be found in the {@link #SearchView} array.
          @attr name android:imeOptions
        */
        public static int SearchView_android_imeOptions = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#inputType}
          attribute's value can be found in the {@link #SearchView} array.
          @attr name android:inputType
        */
        public static int SearchView_android_inputType = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#maxWidth}
          attribute's value can be found in the {@link #SearchView} array.
          @attr name android:maxWidth
        */
        public static int SearchView_android_maxWidth = 1;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#closeIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:closeIcon
        */
        public static int SearchView_closeIcon = 8;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#commitIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:commitIcon
        */
        public static int SearchView_commitIcon = 13;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#defaultQueryHint}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:defaultQueryHint
        */
        public static int SearchView_defaultQueryHint = 7;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#goIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:goIcon
        */
        public static int SearchView_goIcon = 9;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#iconifiedByDefault}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:iconifiedByDefault
        */
        public static int SearchView_iconifiedByDefault = 5;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#layout}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:layout
        */
        public static int SearchView_layout = 4;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#queryBackground}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:queryBackground
        */
        public static int SearchView_queryBackground = 15;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#queryHint}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:queryHint
        */
        public static int SearchView_queryHint = 6;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#searchHintIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:searchHintIcon
        */
        public static int SearchView_searchHintIcon = 11;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#searchIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:searchIcon
        */
        public static int SearchView_searchIcon = 10;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#submitBackground}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:submitBackground
        */
        public static int SearchView_submitBackground = 16;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#suggestionRowLayout}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:suggestionRowLayout
        */
        public static int SearchView_suggestionRowLayout = 14;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#voiceIcon}
          attribute's value can be found in the {@link #SearchView} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:voiceIcon
        */
        public static int SearchView_voiceIcon = 12;
        /** Attributes that can be used with a Spinner.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #Spinner_android_dropDownWidth android:dropDownWidth}</code></td><td></td></tr>
           <tr><td><code>{@link #Spinner_android_popupBackground android:popupBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Spinner_android_prompt android:prompt}</code></td><td></td></tr>
           <tr><td><code>{@link #Spinner_popupTheme com.reactlibrary:popupTheme}</code></td><td></td></tr>
           </table>
           @see #Spinner_android_dropDownWidth
           @see #Spinner_android_popupBackground
           @see #Spinner_android_prompt
           @see #Spinner_popupTheme
         */
        public static final int[] Spinner = {
            0x01010176, 0x0101017b, 0x01010262, 0x7f01001b
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#dropDownWidth}
          attribute's value can be found in the {@link #Spinner} array.
          @attr name android:dropDownWidth
        */
        public static int Spinner_android_dropDownWidth = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#popupBackground}
          attribute's value can be found in the {@link #Spinner} array.
          @attr name android:popupBackground
        */
        public static int Spinner_android_popupBackground = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#prompt}
          attribute's value can be found in the {@link #Spinner} array.
          @attr name android:prompt
        */
        public static int Spinner_android_prompt = 1;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#popupTheme}
          attribute's value can be found in the {@link #Spinner} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:popupTheme
        */
        public static int Spinner_popupTheme = 3;
        /** Attributes that can be used with a SwitchCompat.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #SwitchCompat_android_textOff android:textOff}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_android_textOn android:textOn}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_android_thumb android:thumb}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_showText com.reactlibrary:showText}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_splitTrack com.reactlibrary:splitTrack}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_switchMinWidth com.reactlibrary:switchMinWidth}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_switchPadding com.reactlibrary:switchPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_switchTextAppearance com.reactlibrary:switchTextAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_thumbTextPadding com.reactlibrary:thumbTextPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #SwitchCompat_track com.reactlibrary:track}</code></td><td></td></tr>
           </table>
           @see #SwitchCompat_android_textOff
           @see #SwitchCompat_android_textOn
           @see #SwitchCompat_android_thumb
           @see #SwitchCompat_showText
           @see #SwitchCompat_splitTrack
           @see #SwitchCompat_switchMinWidth
           @see #SwitchCompat_switchPadding
           @see #SwitchCompat_switchTextAppearance
           @see #SwitchCompat_thumbTextPadding
           @see #SwitchCompat_track
         */
        public static final int[] SwitchCompat = {
            0x01010124, 0x01010125, 0x01010142, 0x7f010062,
            0x7f010063, 0x7f010064, 0x7f010065, 0x7f010066,
            0x7f010067, 0x7f010068
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textOff}
          attribute's value can be found in the {@link #SwitchCompat} array.
          @attr name android:textOff
        */
        public static int SwitchCompat_android_textOff = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textOn}
          attribute's value can be found in the {@link #SwitchCompat} array.
          @attr name android:textOn
        */
        public static int SwitchCompat_android_textOn = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#thumb}
          attribute's value can be found in the {@link #SwitchCompat} array.
          @attr name android:thumb
        */
        public static int SwitchCompat_android_thumb = 2;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#showText}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:showText
        */
        public static int SwitchCompat_showText = 9;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#splitTrack}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:splitTrack
        */
        public static int SwitchCompat_splitTrack = 8;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#switchMinWidth}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:switchMinWidth
        */
        public static int SwitchCompat_switchMinWidth = 6;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#switchPadding}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:switchPadding
        */
        public static int SwitchCompat_switchPadding = 7;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#switchTextAppearance}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:switchTextAppearance
        */
        public static int SwitchCompat_switchTextAppearance = 5;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#thumbTextPadding}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:thumbTextPadding
        */
        public static int SwitchCompat_thumbTextPadding = 4;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#track}
          attribute's value can be found in the {@link #SwitchCompat} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:track
        */
        public static int SwitchCompat_track = 3;
        /** Attributes that can be used with a TextAppearance.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #TextAppearance_android_textColor android:textColor}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_android_textSize android:textSize}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_android_textStyle android:textStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_android_typeface android:typeface}</code></td><td></td></tr>
           <tr><td><code>{@link #TextAppearance_textAllCaps com.reactlibrary:textAllCaps}</code></td><td></td></tr>
           </table>
           @see #TextAppearance_android_textColor
           @see #TextAppearance_android_textSize
           @see #TextAppearance_android_textStyle
           @see #TextAppearance_android_typeface
           @see #TextAppearance_textAllCaps
         */
        public static final int[] TextAppearance = {
            0x01010095, 0x01010096, 0x01010097, 0x01010098,
            0x7f010024
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textColor}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:textColor
        */
        public static int TextAppearance_android_textColor = 3;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textSize}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:textSize
        */
        public static int TextAppearance_android_textSize = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#textStyle}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:textStyle
        */
        public static int TextAppearance_android_textStyle = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#typeface}
          attribute's value can be found in the {@link #TextAppearance} array.
          @attr name android:typeface
        */
        public static int TextAppearance_android_typeface = 1;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#textAllCaps}
          attribute's value can be found in the {@link #TextAppearance} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a boolean value, either "<code>true</code>" or "<code>false</code>".
          @attr name com.reactlibrary:textAllCaps
        */
        public static int TextAppearance_textAllCaps = 4;
        /** Attributes that can be used with a Theme.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #Theme_actionBarDivider com.reactlibrary:actionBarDivider}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarItemBackground com.reactlibrary:actionBarItemBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarPopupTheme com.reactlibrary:actionBarPopupTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarSize com.reactlibrary:actionBarSize}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarSplitStyle com.reactlibrary:actionBarSplitStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarStyle com.reactlibrary:actionBarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarTabBarStyle com.reactlibrary:actionBarTabBarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarTabStyle com.reactlibrary:actionBarTabStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarTabTextStyle com.reactlibrary:actionBarTabTextStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarTheme com.reactlibrary:actionBarTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionBarWidgetTheme com.reactlibrary:actionBarWidgetTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionButtonStyle com.reactlibrary:actionButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionDropDownStyle com.reactlibrary:actionDropDownStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionMenuTextAppearance com.reactlibrary:actionMenuTextAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionMenuTextColor com.reactlibrary:actionMenuTextColor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeBackground com.reactlibrary:actionModeBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeCloseButtonStyle com.reactlibrary:actionModeCloseButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeCloseDrawable com.reactlibrary:actionModeCloseDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeCopyDrawable com.reactlibrary:actionModeCopyDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeCutDrawable com.reactlibrary:actionModeCutDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeFindDrawable com.reactlibrary:actionModeFindDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModePasteDrawable com.reactlibrary:actionModePasteDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModePopupWindowStyle com.reactlibrary:actionModePopupWindowStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeSelectAllDrawable com.reactlibrary:actionModeSelectAllDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeShareDrawable com.reactlibrary:actionModeShareDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeSplitBackground com.reactlibrary:actionModeSplitBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeStyle com.reactlibrary:actionModeStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionModeWebSearchDrawable com.reactlibrary:actionModeWebSearchDrawable}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionOverflowButtonStyle com.reactlibrary:actionOverflowButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_actionOverflowMenuStyle com.reactlibrary:actionOverflowMenuStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_activityChooserViewStyle com.reactlibrary:activityChooserViewStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_alertDialogButtonGroupStyle com.reactlibrary:alertDialogButtonGroupStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_alertDialogCenterButtons com.reactlibrary:alertDialogCenterButtons}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_alertDialogStyle com.reactlibrary:alertDialogStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_alertDialogTheme com.reactlibrary:alertDialogTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_android_windowAnimationStyle android:windowAnimationStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_android_windowIsFloating android:windowIsFloating}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_autoCompleteTextViewStyle com.reactlibrary:autoCompleteTextViewStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_borderlessButtonStyle com.reactlibrary:borderlessButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonBarButtonStyle com.reactlibrary:buttonBarButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonBarNegativeButtonStyle com.reactlibrary:buttonBarNegativeButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonBarNeutralButtonStyle com.reactlibrary:buttonBarNeutralButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonBarPositiveButtonStyle com.reactlibrary:buttonBarPositiveButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonBarStyle com.reactlibrary:buttonBarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonStyle com.reactlibrary:buttonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_buttonStyleSmall com.reactlibrary:buttonStyleSmall}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_checkboxStyle com.reactlibrary:checkboxStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_checkedTextViewStyle com.reactlibrary:checkedTextViewStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorAccent com.reactlibrary:colorAccent}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorButtonNormal com.reactlibrary:colorButtonNormal}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorControlActivated com.reactlibrary:colorControlActivated}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorControlHighlight com.reactlibrary:colorControlHighlight}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorControlNormal com.reactlibrary:colorControlNormal}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorPrimary com.reactlibrary:colorPrimary}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorPrimaryDark com.reactlibrary:colorPrimaryDark}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_colorSwitchThumbNormal com.reactlibrary:colorSwitchThumbNormal}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_controlBackground com.reactlibrary:controlBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dialogPreferredPadding com.reactlibrary:dialogPreferredPadding}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dialogTheme com.reactlibrary:dialogTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dividerHorizontal com.reactlibrary:dividerHorizontal}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dividerVertical com.reactlibrary:dividerVertical}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dropDownListViewStyle com.reactlibrary:dropDownListViewStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_dropdownListPreferredItemHeight com.reactlibrary:dropdownListPreferredItemHeight}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_editTextBackground com.reactlibrary:editTextBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_editTextColor com.reactlibrary:editTextColor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_editTextStyle com.reactlibrary:editTextStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_homeAsUpIndicator com.reactlibrary:homeAsUpIndicator}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listChoiceBackgroundIndicator com.reactlibrary:listChoiceBackgroundIndicator}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listDividerAlertDialog com.reactlibrary:listDividerAlertDialog}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPopupWindowStyle com.reactlibrary:listPopupWindowStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPreferredItemHeight com.reactlibrary:listPreferredItemHeight}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPreferredItemHeightLarge com.reactlibrary:listPreferredItemHeightLarge}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPreferredItemHeightSmall com.reactlibrary:listPreferredItemHeightSmall}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPreferredItemPaddingLeft com.reactlibrary:listPreferredItemPaddingLeft}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_listPreferredItemPaddingRight com.reactlibrary:listPreferredItemPaddingRight}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_panelBackground com.reactlibrary:panelBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_panelMenuListTheme com.reactlibrary:panelMenuListTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_panelMenuListWidth com.reactlibrary:panelMenuListWidth}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_popupMenuStyle com.reactlibrary:popupMenuStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_popupWindowStyle com.reactlibrary:popupWindowStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_radioButtonStyle com.reactlibrary:radioButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_ratingBarStyle com.reactlibrary:ratingBarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_searchViewStyle com.reactlibrary:searchViewStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_selectableItemBackground com.reactlibrary:selectableItemBackground}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_selectableItemBackgroundBorderless com.reactlibrary:selectableItemBackgroundBorderless}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_spinnerDropDownItemStyle com.reactlibrary:spinnerDropDownItemStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_spinnerStyle com.reactlibrary:spinnerStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_switchStyle com.reactlibrary:switchStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceLargePopupMenu com.reactlibrary:textAppearanceLargePopupMenu}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceListItem com.reactlibrary:textAppearanceListItem}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceListItemSmall com.reactlibrary:textAppearanceListItemSmall}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceSearchResultSubtitle com.reactlibrary:textAppearanceSearchResultSubtitle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceSearchResultTitle com.reactlibrary:textAppearanceSearchResultTitle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textAppearanceSmallPopupMenu com.reactlibrary:textAppearanceSmallPopupMenu}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textColorAlertDialogListItem com.reactlibrary:textColorAlertDialogListItem}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_textColorSearchUrl com.reactlibrary:textColorSearchUrl}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_toolbarNavigationButtonStyle com.reactlibrary:toolbarNavigationButtonStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_toolbarStyle com.reactlibrary:toolbarStyle}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowActionBar com.reactlibrary:windowActionBar}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowActionBarOverlay com.reactlibrary:windowActionBarOverlay}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowActionModeOverlay com.reactlibrary:windowActionModeOverlay}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowFixedHeightMajor com.reactlibrary:windowFixedHeightMajor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowFixedHeightMinor com.reactlibrary:windowFixedHeightMinor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowFixedWidthMajor com.reactlibrary:windowFixedWidthMajor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowFixedWidthMinor com.reactlibrary:windowFixedWidthMinor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowMinWidthMajor com.reactlibrary:windowMinWidthMajor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowMinWidthMinor com.reactlibrary:windowMinWidthMinor}</code></td><td></td></tr>
           <tr><td><code>{@link #Theme_windowNoTitle com.reactlibrary:windowNoTitle}</code></td><td></td></tr>
           </table>
           @see #Theme_actionBarDivider
           @see #Theme_actionBarItemBackground
           @see #Theme_actionBarPopupTheme
           @see #Theme_actionBarSize
           @see #Theme_actionBarSplitStyle
           @see #Theme_actionBarStyle
           @see #Theme_actionBarTabBarStyle
           @see #Theme_actionBarTabStyle
           @see #Theme_actionBarTabTextStyle
           @see #Theme_actionBarTheme
           @see #Theme_actionBarWidgetTheme
           @see #Theme_actionButtonStyle
           @see #Theme_actionDropDownStyle
           @see #Theme_actionMenuTextAppearance
           @see #Theme_actionMenuTextColor
           @see #Theme_actionModeBackground
           @see #Theme_actionModeCloseButtonStyle
           @see #Theme_actionModeCloseDrawable
           @see #Theme_actionModeCopyDrawable
           @see #Theme_actionModeCutDrawable
           @see #Theme_actionModeFindDrawable
           @see #Theme_actionModePasteDrawable
           @see #Theme_actionModePopupWindowStyle
           @see #Theme_actionModeSelectAllDrawable
           @see #Theme_actionModeShareDrawable
           @see #Theme_actionModeSplitBackground
           @see #Theme_actionModeStyle
           @see #Theme_actionModeWebSearchDrawable
           @see #Theme_actionOverflowButtonStyle
           @see #Theme_actionOverflowMenuStyle
           @see #Theme_activityChooserViewStyle
           @see #Theme_alertDialogButtonGroupStyle
           @see #Theme_alertDialogCenterButtons
           @see #Theme_alertDialogStyle
           @see #Theme_alertDialogTheme
           @see #Theme_android_windowAnimationStyle
           @see #Theme_android_windowIsFloating
           @see #Theme_autoCompleteTextViewStyle
           @see #Theme_borderlessButtonStyle
           @see #Theme_buttonBarButtonStyle
           @see #Theme_buttonBarNegativeButtonStyle
           @see #Theme_buttonBarNeutralButtonStyle
           @see #Theme_buttonBarPositiveButtonStyle
           @see #Theme_buttonBarStyle
           @see #Theme_buttonStyle
           @see #Theme_buttonStyleSmall
           @see #Theme_checkboxStyle
           @see #Theme_checkedTextViewStyle
           @see #Theme_colorAccent
           @see #Theme_colorButtonNormal
           @see #Theme_colorControlActivated
           @see #Theme_colorControlHighlight
           @see #Theme_colorControlNormal
           @see #Theme_colorPrimary
           @see #Theme_colorPrimaryDark
           @see #Theme_colorSwitchThumbNormal
           @see #Theme_controlBackground
           @see #Theme_dialogPreferredPadding
           @see #Theme_dialogTheme
           @see #Theme_dividerHorizontal
           @see #Theme_dividerVertical
           @see #Theme_dropDownListViewStyle
           @see #Theme_dropdownListPreferredItemHeight
           @see #Theme_editTextBackground
           @see #Theme_editTextColor
           @see #Theme_editTextStyle
           @see #Theme_homeAsUpIndicator
           @see #Theme_listChoiceBackgroundIndicator
           @see #Theme_listDividerAlertDialog
           @see #Theme_listPopupWindowStyle
           @see #Theme_listPreferredItemHeight
           @see #Theme_listPreferredItemHeightLarge
           @see #Theme_listPreferredItemHeightSmall
           @see #Theme_listPreferredItemPaddingLeft
           @see #Theme_listPreferredItemPaddingRight
           @see #Theme_panelBackground
           @see #Theme_panelMenuListTheme
           @see #Theme_panelMenuListWidth
           @see #Theme_popupMenuStyle
           @see #Theme_popupWindowStyle
           @see #Theme_radioButtonStyle
           @see #Theme_ratingBarStyle
           @see #Theme_searchViewStyle
           @see #Theme_selectableItemBackground
           @see #Theme_selectableItemBackgroundBorderless
           @see #Theme_spinnerDropDownItemStyle
           @see #Theme_spinnerStyle
           @see #Theme_switchStyle
           @see #Theme_textAppearanceLargePopupMenu
           @see #Theme_textAppearanceListItem
           @see #Theme_textAppearanceListItemSmall
           @see #Theme_textAppearanceSearchResultSubtitle
           @see #Theme_textAppearanceSearchResultTitle
           @see #Theme_textAppearanceSmallPopupMenu
           @see #Theme_textColorAlertDialogListItem
           @see #Theme_textColorSearchUrl
           @see #Theme_toolbarNavigationButtonStyle
           @see #Theme_toolbarStyle
           @see #Theme_windowActionBar
           @see #Theme_windowActionBarOverlay
           @see #Theme_windowActionModeOverlay
           @see #Theme_windowFixedHeightMajor
           @see #Theme_windowFixedHeightMinor
           @see #Theme_windowFixedWidthMajor
           @see #Theme_windowFixedWidthMinor
           @see #Theme_windowMinWidthMajor
           @see #Theme_windowMinWidthMinor
           @see #Theme_windowNoTitle
         */
        public static final int[] Theme = {
            0x01010057, 0x010100ae, 0x7f010069, 0x7f01006a,
            0x7f01006b, 0x7f01006c, 0x7f01006d, 0x7f01006e,
            0x7f01006f, 0x7f010070, 0x7f010071, 0x7f010072,
            0x7f010073, 0x7f010074, 0x7f010075, 0x7f010076,
            0x7f010077, 0x7f010078, 0x7f010079, 0x7f01007a,
            0x7f01007b, 0x7f01007c, 0x7f01007d, 0x7f01007e,
            0x7f01007f, 0x7f010080, 0x7f010081, 0x7f010082,
            0x7f010083, 0x7f010084, 0x7f010085, 0x7f010086,
            0x7f010087, 0x7f010088, 0x7f010089, 0x7f01008a,
            0x7f01008b, 0x7f01008c, 0x7f01008d, 0x7f01008e,
            0x7f01008f, 0x7f010090, 0x7f010091, 0x7f010092,
            0x7f010093, 0x7f010094, 0x7f010095, 0x7f010096,
            0x7f010097, 0x7f010098, 0x7f010099, 0x7f01009a,
            0x7f01009b, 0x7f01009c, 0x7f01009d, 0x7f01009e,
            0x7f01009f, 0x7f0100a0, 0x7f0100a1, 0x7f0100a2,
            0x7f0100a3, 0x7f0100a4, 0x7f0100a5, 0x7f0100a6,
            0x7f0100a7, 0x7f0100a8, 0x7f0100a9, 0x7f0100aa,
            0x7f0100ab, 0x7f0100ac, 0x7f0100ad, 0x7f0100ae,
            0x7f0100af, 0x7f0100b0, 0x7f0100b1, 0x7f0100b2,
            0x7f0100b3, 0x7f0100b4, 0x7f0100b5, 0x7f0100b6,
            0x7f0100b7, 0x7f0100b8, 0x7f0100b9, 0x7f0100ba,
            0x7f0100bb, 0x7f0100bc, 0x7f0100bd, 0x7f0100be,
            0x7f0100bf, 0x7f0100c0, 0x7f0100c1, 0x7f0100c2,
            0x7f0100c3, 0x7f0100c4, 0x7f0100c5, 0x7f0100c6,
            0x7f0100c7, 0x7f0100c8, 0x7f0100c9, 0x7f0100ca,
            0x7f0100cb, 0x7f0100cc, 0x7f0100cd, 0x7f0100ce,
            0x7f0100cf, 0x7f0100d0, 0x7f0100d1, 0x7f0100d2
        };
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionBarDivider}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionBarDivider
        */
        public static int Theme_actionBarDivider = 23;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionBarItemBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionBarItemBackground
        */
        public static int Theme_actionBarItemBackground = 24;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionBarPopupTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionBarPopupTheme
        */
        public static int Theme_actionBarPopupTheme = 17;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionBarSize}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
<p>May be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>wrap_content</code></td><td>0</td><td></td></tr>
</table>
          @attr name com.reactlibrary:actionBarSize
        */
        public static int Theme_actionBarSize = 22;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionBarSplitStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionBarSplitStyle
        */
        public static int Theme_actionBarSplitStyle = 19;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionBarStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionBarStyle
        */
        public static int Theme_actionBarStyle = 18;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionBarTabBarStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionBarTabBarStyle
        */
        public static int Theme_actionBarTabBarStyle = 13;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionBarTabStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionBarTabStyle
        */
        public static int Theme_actionBarTabStyle = 12;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionBarTabTextStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionBarTabTextStyle
        */
        public static int Theme_actionBarTabTextStyle = 14;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionBarTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionBarTheme
        */
        public static int Theme_actionBarTheme = 20;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionBarWidgetTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionBarWidgetTheme
        */
        public static int Theme_actionBarWidgetTheme = 21;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionButtonStyle
        */
        public static int Theme_actionButtonStyle = 49;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionDropDownStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionDropDownStyle
        */
        public static int Theme_actionDropDownStyle = 45;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionMenuTextAppearance}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionMenuTextAppearance
        */
        public static int Theme_actionMenuTextAppearance = 25;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionMenuTextColor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.reactlibrary:actionMenuTextColor
        */
        public static int Theme_actionMenuTextColor = 26;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModeBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModeBackground
        */
        public static int Theme_actionModeBackground = 29;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModeCloseButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModeCloseButtonStyle
        */
        public static int Theme_actionModeCloseButtonStyle = 28;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModeCloseDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModeCloseDrawable
        */
        public static int Theme_actionModeCloseDrawable = 31;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModeCopyDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModeCopyDrawable
        */
        public static int Theme_actionModeCopyDrawable = 33;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModeCutDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModeCutDrawable
        */
        public static int Theme_actionModeCutDrawable = 32;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModeFindDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModeFindDrawable
        */
        public static int Theme_actionModeFindDrawable = 37;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModePasteDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModePasteDrawable
        */
        public static int Theme_actionModePasteDrawable = 34;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModePopupWindowStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModePopupWindowStyle
        */
        public static int Theme_actionModePopupWindowStyle = 39;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModeSelectAllDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModeSelectAllDrawable
        */
        public static int Theme_actionModeSelectAllDrawable = 35;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModeShareDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModeShareDrawable
        */
        public static int Theme_actionModeShareDrawable = 36;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModeSplitBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModeSplitBackground
        */
        public static int Theme_actionModeSplitBackground = 30;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModeStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModeStyle
        */
        public static int Theme_actionModeStyle = 27;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionModeWebSearchDrawable}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionModeWebSearchDrawable
        */
        public static int Theme_actionModeWebSearchDrawable = 38;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionOverflowButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionOverflowButtonStyle
        */
        public static int Theme_actionOverflowButtonStyle = 15;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#actionOverflowMenuStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:actionOverflowMenuStyle
        */
        public static int Theme_actionOverflowMenuStyle = 16;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#activityChooserViewStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:activityChooserViewStyle
        */
        public static int Theme_activityChooserViewStyle = 57;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#alertDialogButtonGroupStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:alertDialogButtonGroupStyle
        */
        public static int Theme_alertDialogButtonGroupStyle = 91;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#alertDialogCenterButtons}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:alertDialogCenterButtons
        */
        public static int Theme_alertDialogCenterButtons = 92;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#alertDialogStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:alertDialogStyle
        */
        public static int Theme_alertDialogStyle = 90;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#alertDialogTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:alertDialogTheme
        */
        public static int Theme_alertDialogTheme = 93;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#windowAnimationStyle}
          attribute's value can be found in the {@link #Theme} array.
          @attr name android:windowAnimationStyle
        */
        public static int Theme_android_windowAnimationStyle = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#windowIsFloating}
          attribute's value can be found in the {@link #Theme} array.
          @attr name android:windowIsFloating
        */
        public static int Theme_android_windowIsFloating = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#autoCompleteTextViewStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:autoCompleteTextViewStyle
        */
        public static int Theme_autoCompleteTextViewStyle = 98;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#borderlessButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:borderlessButtonStyle
        */
        public static int Theme_borderlessButtonStyle = 54;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#buttonBarButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:buttonBarButtonStyle
        */
        public static int Theme_buttonBarButtonStyle = 51;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#buttonBarNegativeButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:buttonBarNegativeButtonStyle
        */
        public static int Theme_buttonBarNegativeButtonStyle = 96;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#buttonBarNeutralButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:buttonBarNeutralButtonStyle
        */
        public static int Theme_buttonBarNeutralButtonStyle = 97;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#buttonBarPositiveButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:buttonBarPositiveButtonStyle
        */
        public static int Theme_buttonBarPositiveButtonStyle = 95;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#buttonBarStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:buttonBarStyle
        */
        public static int Theme_buttonBarStyle = 50;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#buttonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:buttonStyle
        */
        public static int Theme_buttonStyle = 99;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#buttonStyleSmall}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:buttonStyleSmall
        */
        public static int Theme_buttonStyleSmall = 100;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#checkboxStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:checkboxStyle
        */
        public static int Theme_checkboxStyle = 101;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#checkedTextViewStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:checkedTextViewStyle
        */
        public static int Theme_checkedTextViewStyle = 102;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#colorAccent}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:colorAccent
        */
        public static int Theme_colorAccent = 83;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#colorButtonNormal}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:colorButtonNormal
        */
        public static int Theme_colorButtonNormal = 87;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#colorControlActivated}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:colorControlActivated
        */
        public static int Theme_colorControlActivated = 85;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#colorControlHighlight}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:colorControlHighlight
        */
        public static int Theme_colorControlHighlight = 86;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#colorControlNormal}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:colorControlNormal
        */
        public static int Theme_colorControlNormal = 84;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#colorPrimary}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:colorPrimary
        */
        public static int Theme_colorPrimary = 81;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#colorPrimaryDark}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:colorPrimaryDark
        */
        public static int Theme_colorPrimaryDark = 82;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#colorSwitchThumbNormal}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:colorSwitchThumbNormal
        */
        public static int Theme_colorSwitchThumbNormal = 88;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#controlBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:controlBackground
        */
        public static int Theme_controlBackground = 89;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#dialogPreferredPadding}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:dialogPreferredPadding
        */
        public static int Theme_dialogPreferredPadding = 43;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#dialogTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:dialogTheme
        */
        public static int Theme_dialogTheme = 42;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#dividerHorizontal}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:dividerHorizontal
        */
        public static int Theme_dividerHorizontal = 56;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#dividerVertical}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:dividerVertical
        */
        public static int Theme_dividerVertical = 55;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#dropDownListViewStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:dropDownListViewStyle
        */
        public static int Theme_dropDownListViewStyle = 73;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#dropdownListPreferredItemHeight}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:dropdownListPreferredItemHeight
        */
        public static int Theme_dropdownListPreferredItemHeight = 46;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#editTextBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:editTextBackground
        */
        public static int Theme_editTextBackground = 63;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#editTextColor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.reactlibrary:editTextColor
        */
        public static int Theme_editTextColor = 62;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#editTextStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:editTextStyle
        */
        public static int Theme_editTextStyle = 103;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#homeAsUpIndicator}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:homeAsUpIndicator
        */
        public static int Theme_homeAsUpIndicator = 48;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#listChoiceBackgroundIndicator}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:listChoiceBackgroundIndicator
        */
        public static int Theme_listChoiceBackgroundIndicator = 80;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#listDividerAlertDialog}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:listDividerAlertDialog
        */
        public static int Theme_listDividerAlertDialog = 44;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#listPopupWindowStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:listPopupWindowStyle
        */
        public static int Theme_listPopupWindowStyle = 74;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#listPreferredItemHeight}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:listPreferredItemHeight
        */
        public static int Theme_listPreferredItemHeight = 68;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#listPreferredItemHeightLarge}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:listPreferredItemHeightLarge
        */
        public static int Theme_listPreferredItemHeightLarge = 70;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#listPreferredItemHeightSmall}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:listPreferredItemHeightSmall
        */
        public static int Theme_listPreferredItemHeightSmall = 69;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#listPreferredItemPaddingLeft}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:listPreferredItemPaddingLeft
        */
        public static int Theme_listPreferredItemPaddingLeft = 71;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#listPreferredItemPaddingRight}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:listPreferredItemPaddingRight
        */
        public static int Theme_listPreferredItemPaddingRight = 72;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#panelBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:panelBackground
        */
        public static int Theme_panelBackground = 77;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#panelMenuListTheme}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:panelMenuListTheme
        */
        public static int Theme_panelMenuListTheme = 79;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#panelMenuListWidth}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:panelMenuListWidth
        */
        public static int Theme_panelMenuListWidth = 78;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#popupMenuStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:popupMenuStyle
        */
        public static int Theme_popupMenuStyle = 60;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#popupWindowStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:popupWindowStyle
        */
        public static int Theme_popupWindowStyle = 61;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#radioButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:radioButtonStyle
        */
        public static int Theme_radioButtonStyle = 104;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#ratingBarStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:ratingBarStyle
        */
        public static int Theme_ratingBarStyle = 105;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#searchViewStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:searchViewStyle
        */
        public static int Theme_searchViewStyle = 67;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#selectableItemBackground}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:selectableItemBackground
        */
        public static int Theme_selectableItemBackground = 52;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#selectableItemBackgroundBorderless}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:selectableItemBackgroundBorderless
        */
        public static int Theme_selectableItemBackgroundBorderless = 53;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#spinnerDropDownItemStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:spinnerDropDownItemStyle
        */
        public static int Theme_spinnerDropDownItemStyle = 47;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#spinnerStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:spinnerStyle
        */
        public static int Theme_spinnerStyle = 106;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#switchStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:switchStyle
        */
        public static int Theme_switchStyle = 107;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#textAppearanceLargePopupMenu}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:textAppearanceLargePopupMenu
        */
        public static int Theme_textAppearanceLargePopupMenu = 40;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#textAppearanceListItem}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:textAppearanceListItem
        */
        public static int Theme_textAppearanceListItem = 75;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#textAppearanceListItemSmall}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:textAppearanceListItemSmall
        */
        public static int Theme_textAppearanceListItemSmall = 76;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#textAppearanceSearchResultSubtitle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:textAppearanceSearchResultSubtitle
        */
        public static int Theme_textAppearanceSearchResultSubtitle = 65;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#textAppearanceSearchResultTitle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:textAppearanceSearchResultTitle
        */
        public static int Theme_textAppearanceSearchResultTitle = 64;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#textAppearanceSmallPopupMenu}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:textAppearanceSmallPopupMenu
        */
        public static int Theme_textAppearanceSmallPopupMenu = 41;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#textColorAlertDialogListItem}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.reactlibrary:textColorAlertDialogListItem
        */
        public static int Theme_textColorAlertDialogListItem = 94;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#textColorSearchUrl}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
<p>May be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
          @attr name com.reactlibrary:textColorSearchUrl
        */
        public static int Theme_textColorSearchUrl = 66;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#toolbarNavigationButtonStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:toolbarNavigationButtonStyle
        */
        public static int Theme_toolbarNavigationButtonStyle = 59;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#toolbarStyle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:toolbarStyle
        */
        public static int Theme_toolbarStyle = 58;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#windowActionBar}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:windowActionBar
        */
        public static int Theme_windowActionBar = 2;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#windowActionBarOverlay}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:windowActionBarOverlay
        */
        public static int Theme_windowActionBarOverlay = 4;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#windowActionModeOverlay}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:windowActionModeOverlay
        */
        public static int Theme_windowActionModeOverlay = 5;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#windowFixedHeightMajor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:windowFixedHeightMajor
        */
        public static int Theme_windowFixedHeightMajor = 9;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#windowFixedHeightMinor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:windowFixedHeightMinor
        */
        public static int Theme_windowFixedHeightMinor = 7;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#windowFixedWidthMajor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:windowFixedWidthMajor
        */
        public static int Theme_windowFixedWidthMajor = 6;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#windowFixedWidthMinor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:windowFixedWidthMinor
        */
        public static int Theme_windowFixedWidthMinor = 8;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#windowMinWidthMajor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:windowMinWidthMajor
        */
        public static int Theme_windowMinWidthMajor = 10;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#windowMinWidthMinor}
          attribute's value can be found in the {@link #Theme} array.


          <p>May be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>May be a fractional value, which is a floating point number appended with either % or %p, such as "<code>14.5%</code>".
The % suffix always means a percentage of the base size; the optional %p suffix provides a size relative to
some parent container.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:windowMinWidthMinor
        */
        public static int Theme_windowMinWidthMinor = 11;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#windowNoTitle}
          attribute's value can be found in the {@link #Theme} array.


          <p>Must be a boolean value, either "<code>true</code>" or "<code>false</code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:windowNoTitle
        */
        public static int Theme_windowNoTitle = 3;
        /** Attributes that can be used with a Toolbar.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #Toolbar_android_gravity android:gravity}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_android_minHeight android:minHeight}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_collapseContentDescription com.reactlibrary:collapseContentDescription}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_collapseIcon com.reactlibrary:collapseIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_contentInsetEnd com.reactlibrary:contentInsetEnd}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_contentInsetLeft com.reactlibrary:contentInsetLeft}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_contentInsetRight com.reactlibrary:contentInsetRight}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_contentInsetStart com.reactlibrary:contentInsetStart}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_logo com.reactlibrary:logo}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_logoDescription com.reactlibrary:logoDescription}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_maxButtonHeight com.reactlibrary:maxButtonHeight}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_navigationContentDescription com.reactlibrary:navigationContentDescription}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_navigationIcon com.reactlibrary:navigationIcon}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_popupTheme com.reactlibrary:popupTheme}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_subtitle com.reactlibrary:subtitle}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_subtitleTextAppearance com.reactlibrary:subtitleTextAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_subtitleTextColor com.reactlibrary:subtitleTextColor}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_title com.reactlibrary:title}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleMarginBottom com.reactlibrary:titleMarginBottom}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleMarginEnd com.reactlibrary:titleMarginEnd}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleMarginStart com.reactlibrary:titleMarginStart}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleMarginTop com.reactlibrary:titleMarginTop}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleMargins com.reactlibrary:titleMargins}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleTextAppearance com.reactlibrary:titleTextAppearance}</code></td><td></td></tr>
           <tr><td><code>{@link #Toolbar_titleTextColor com.reactlibrary:titleTextColor}</code></td><td></td></tr>
           </table>
           @see #Toolbar_android_gravity
           @see #Toolbar_android_minHeight
           @see #Toolbar_collapseContentDescription
           @see #Toolbar_collapseIcon
           @see #Toolbar_contentInsetEnd
           @see #Toolbar_contentInsetLeft
           @see #Toolbar_contentInsetRight
           @see #Toolbar_contentInsetStart
           @see #Toolbar_logo
           @see #Toolbar_logoDescription
           @see #Toolbar_maxButtonHeight
           @see #Toolbar_navigationContentDescription
           @see #Toolbar_navigationIcon
           @see #Toolbar_popupTheme
           @see #Toolbar_subtitle
           @see #Toolbar_subtitleTextAppearance
           @see #Toolbar_subtitleTextColor
           @see #Toolbar_title
           @see #Toolbar_titleMarginBottom
           @see #Toolbar_titleMarginEnd
           @see #Toolbar_titleMarginStart
           @see #Toolbar_titleMarginTop
           @see #Toolbar_titleMargins
           @see #Toolbar_titleTextAppearance
           @see #Toolbar_titleTextColor
         */
        public static final int[] Toolbar = {
            0x010100af, 0x01010140, 0x7f010003, 0x7f010006,
            0x7f01000a, 0x7f010016, 0x7f010017, 0x7f010018,
            0x7f010019, 0x7f01001b, 0x7f0100d3, 0x7f0100d4,
            0x7f0100d5, 0x7f0100d6, 0x7f0100d7, 0x7f0100d8,
            0x7f0100d9, 0x7f0100da, 0x7f0100db, 0x7f0100dc,
            0x7f0100dd, 0x7f0100de, 0x7f0100df, 0x7f0100e0,
            0x7f0100e1
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#gravity}
          attribute's value can be found in the {@link #Toolbar} array.
          @attr name android:gravity
        */
        public static int Toolbar_android_gravity = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#minHeight}
          attribute's value can be found in the {@link #Toolbar} array.
          @attr name android:minHeight
        */
        public static int Toolbar_android_minHeight = 1;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#collapseContentDescription}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:collapseContentDescription
        */
        public static int Toolbar_collapseContentDescription = 19;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#collapseIcon}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:collapseIcon
        */
        public static int Toolbar_collapseIcon = 18;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#contentInsetEnd}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:contentInsetEnd
        */
        public static int Toolbar_contentInsetEnd = 6;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#contentInsetLeft}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:contentInsetLeft
        */
        public static int Toolbar_contentInsetLeft = 7;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#contentInsetRight}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:contentInsetRight
        */
        public static int Toolbar_contentInsetRight = 8;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#contentInsetStart}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:contentInsetStart
        */
        public static int Toolbar_contentInsetStart = 5;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#logo}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:logo
        */
        public static int Toolbar_logo = 4;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#logoDescription}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:logoDescription
        */
        public static int Toolbar_logoDescription = 22;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#maxButtonHeight}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:maxButtonHeight
        */
        public static int Toolbar_maxButtonHeight = 17;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#navigationContentDescription}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:navigationContentDescription
        */
        public static int Toolbar_navigationContentDescription = 21;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#navigationIcon}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:navigationIcon
        */
        public static int Toolbar_navigationIcon = 20;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#popupTheme}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:popupTheme
        */
        public static int Toolbar_popupTheme = 9;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#subtitle}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:subtitle
        */
        public static int Toolbar_subtitle = 3;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#subtitleTextAppearance}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:subtitleTextAppearance
        */
        public static int Toolbar_subtitleTextAppearance = 11;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#subtitleTextColor}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:subtitleTextColor
        */
        public static int Toolbar_subtitleTextColor = 24;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#title}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a string value, using '\\;' to escape characters such as '\\n' or '\\uxxxx' for a unicode character.
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:title
        */
        public static int Toolbar_title = 2;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#titleMarginBottom}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:titleMarginBottom
        */
        public static int Toolbar_titleMarginBottom = 16;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#titleMarginEnd}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:titleMarginEnd
        */
        public static int Toolbar_titleMarginEnd = 14;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#titleMarginStart}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:titleMarginStart
        */
        public static int Toolbar_titleMarginStart = 13;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#titleMarginTop}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:titleMarginTop
        */
        public static int Toolbar_titleMarginTop = 15;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#titleMargins}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:titleMargins
        */
        public static int Toolbar_titleMargins = 12;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#titleTextAppearance}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:titleTextAppearance
        */
        public static int Toolbar_titleTextAppearance = 10;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#titleTextColor}
          attribute's value can be found in the {@link #Toolbar} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:titleTextColor
        */
        public static int Toolbar_titleTextColor = 23;
        /** Attributes that can be used with a View.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #View_android_focusable android:focusable}</code></td><td></td></tr>
           <tr><td><code>{@link #View_android_theme android:theme}</code></td><td></td></tr>
           <tr><td><code>{@link #View_paddingEnd com.reactlibrary:paddingEnd}</code></td><td></td></tr>
           <tr><td><code>{@link #View_paddingStart com.reactlibrary:paddingStart}</code></td><td></td></tr>
           <tr><td><code>{@link #View_theme com.reactlibrary:theme}</code></td><td></td></tr>
           </table>
           @see #View_android_focusable
           @see #View_android_theme
           @see #View_paddingEnd
           @see #View_paddingStart
           @see #View_theme
         */
        public static final int[] View = {
            0x01010000, 0x010100da, 0x7f0100e2, 0x7f0100e3,
            0x7f0100e4
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#focusable}
          attribute's value can be found in the {@link #View} array.
          @attr name android:focusable
        */
        public static int View_android_focusable = 1;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#theme}
          attribute's value can be found in the {@link #View} array.
          @attr name android:theme
        */
        public static int View_android_theme = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#paddingEnd}
          attribute's value can be found in the {@link #View} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:paddingEnd
        */
        public static int View_paddingEnd = 3;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#paddingStart}
          attribute's value can be found in the {@link #View} array.


          <p>Must be a dimension value, which is a floating point number appended with a unit such as "<code>14.5sp</code>".
Available units are: px (pixels), dp (density-independent pixels), sp (scaled pixels based on preferred font size),
in (inches), mm (millimeters).
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:paddingStart
        */
        public static int View_paddingStart = 2;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#theme}
          attribute's value can be found in the {@link #View} array.


          <p>Must be a reference to another resource, in the form "<code>@[+][<i>package</i>:]<i>type</i>:<i>name</i></code>"
or to a theme attribute in the form "<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>".
          @attr name com.reactlibrary:theme
        */
        public static int View_theme = 4;
        /** Attributes that can be used with a ViewBackgroundHelper.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ViewBackgroundHelper_android_background android:background}</code></td><td></td></tr>
           <tr><td><code>{@link #ViewBackgroundHelper_backgroundTint com.reactlibrary:backgroundTint}</code></td><td></td></tr>
           <tr><td><code>{@link #ViewBackgroundHelper_backgroundTintMode com.reactlibrary:backgroundTintMode}</code></td><td></td></tr>
           </table>
           @see #ViewBackgroundHelper_android_background
           @see #ViewBackgroundHelper_backgroundTint
           @see #ViewBackgroundHelper_backgroundTintMode
         */
        public static final int[] ViewBackgroundHelper = {
            0x010100d4, 0x7f0100e5, 0x7f0100e6
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#background}
          attribute's value can be found in the {@link #ViewBackgroundHelper} array.
          @attr name android:background
        */
        public static int ViewBackgroundHelper_android_background = 0;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#backgroundTint}
          attribute's value can be found in the {@link #ViewBackgroundHelper} array.


          <p>Must be a color value, in the form of "<code>#<i>rgb</i></code>", "<code>#<i>argb</i></code>",
"<code>#<i>rrggbb</i></code>", or "<code>#<i>aarrggbb</i></code>".
<p>This may also be a reference to a resource (in the form
"<code>@[<i>package</i>:]<i>type</i>:<i>name</i></code>") or
theme attribute (in the form
"<code>?[<i>package</i>:][<i>type</i>:]<i>name</i></code>")
containing a value of this type.
          @attr name com.reactlibrary:backgroundTint
        */
        public static int ViewBackgroundHelper_backgroundTint = 1;
        /**
          <p>This symbol is the offset where the {@link com.reactlibrary.R.attr#backgroundTintMode}
          attribute's value can be found in the {@link #ViewBackgroundHelper} array.


          <p>Must be one of the following constant values.</p>
<table>
<colgroup align="left" />
<colgroup align="left" />
<colgroup align="left" />
<tr><th>Constant</th><th>Value</th><th>Description</th></tr>
<tr><td><code>src_over</code></td><td>3</td><td></td></tr>
<tr><td><code>src_in</code></td><td>5</td><td></td></tr>
<tr><td><code>src_atop</code></td><td>9</td><td></td></tr>
<tr><td><code>multiply</code></td><td>14</td><td></td></tr>
<tr><td><code>screen</code></td><td>15</td><td></td></tr>
</table>
          @attr name com.reactlibrary:backgroundTintMode
        */
        public static int ViewBackgroundHelper_backgroundTintMode = 2;
        /** Attributes that can be used with a ViewStubCompat.
           <p>Includes the following attributes:</p>
           <table>
           <colgroup align="left" />
           <colgroup align="left" />
           <tr><th>Attribute</th><th>Description</th></tr>
           <tr><td><code>{@link #ViewStubCompat_android_id android:id}</code></td><td></td></tr>
           <tr><td><code>{@link #ViewStubCompat_android_inflatedId android:inflatedId}</code></td><td></td></tr>
           <tr><td><code>{@link #ViewStubCompat_android_layout android:layout}</code></td><td></td></tr>
           </table>
           @see #ViewStubCompat_android_id
           @see #ViewStubCompat_android_inflatedId
           @see #ViewStubCompat_android_layout
         */
        public static final int[] ViewStubCompat = {
            0x010100d0, 0x010100f2, 0x010100f3
        };
        /**
          <p>This symbol is the offset where the {@link android.R.attr#id}
          attribute's value can be found in the {@link #ViewStubCompat} array.
          @attr name android:id
        */
        public static int ViewStubCompat_android_id = 0;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#inflatedId}
          attribute's value can be found in the {@link #ViewStubCompat} array.
          @attr name android:inflatedId
        */
        public static int ViewStubCompat_android_inflatedId = 2;
        /**
          <p>This symbol is the offset where the {@link android.R.attr#layout}
          attribute's value can be found in the {@link #ViewStubCompat} array.
          @attr name android:layout
        */
        public static int ViewStubCompat_android_layout = 1;
    };
}
